// Code generated by wincallback.go using 'go generate'. DO NOT EDIT.

//go:build darwin || freebsd || linux || netbsd

// External code calls into callbackasm at an offset corresponding
// to the callback index. Callbackasm is a table of MOV and JMP instructions.
// Since Go 1.26, MOV instructions with immediate values lower than or equal to 32
// are encoded in 2 bytes rather than 4 bytes, which breaks the assumption that each
// callback entry is 8 bytes long. Therefore, for callback indices less than or equal to 32,
// add a PCALIGN directive to align the next instruction to an 8-byte boundary.
// The MOV instruction loads X7 with the callback index, and the
// JMP instruction branches to callbackasm1.
// callbackasm1 takes the callback index from X7 and
// indexes into an array that stores information about each callback.
// It then calls the Go implementation for that callback.
#include "textflag.h"

TEXT callbackasm(SB), NOSPLIT|NOFRAME, $0
	PCALIGN $8
	MOV     $0, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $1, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $2, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $3, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $4, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $5, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $6, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $7, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $8, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $9, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $10, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $11, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $12, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $13, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $14, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $15, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $16, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $17, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $18, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $19, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $20, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $21, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $22, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $23, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $24, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $25, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $26, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $27, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $28, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $29, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $30, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $31, X7
	JMP     callbackasm1(SB)
	PCALIGN $8
	MOV     $32, X7
	JMP     callbackasm1(SB)
	MOV $33, X7
	JMP callbackasm1(SB)
	MOV $34, X7
	JMP callbackasm1(SB)
	MOV $35, X7
	JMP callbackasm1(SB)
	MOV $36, X7
	JMP callbackasm1(SB)
	MOV $37, X7
	JMP callbackasm1(SB)
	MOV $38, X7
	JMP callbackasm1(SB)
	MOV $39, X7
	JMP callbackasm1(SB)
	MOV $40, X7
	JMP callbackasm1(SB)
	MOV $41, X7
	JMP callbackasm1(SB)
	MOV $42, X7
	JMP callbackasm1(SB)
	MOV $43, X7
	JMP callbackasm1(SB)
	MOV $44, X7
	JMP callbackasm1(SB)
	MOV $45, X7
	JMP callbackasm1(SB)
	MOV $46, X7
	JMP callbackasm1(SB)
	MOV $47, X7
	JMP callbackasm1(SB)
	MOV $48, X7
	JMP callbackasm1(SB)
	MOV $49, X7
	JMP callbackasm1(SB)
	MOV $50, X7
	JMP callbackasm1(SB)
	MOV $51, X7
	JMP callbackasm1(SB)
	MOV $52, X7
	JMP callbackasm1(SB)
	MOV $53, X7
	JMP callbackasm1(SB)
	MOV $54, X7
	JMP callbackasm1(SB)
	MOV $55, X7
	JMP callbackasm1(SB)
	MOV $56, X7
	JMP callbackasm1(SB)
	MOV $57, X7
	JMP callbackasm1(SB)
	MOV $58, X7
	JMP callbackasm1(SB)
	MOV $59, X7
	JMP callbackasm1(SB)
	MOV $60, X7
	JMP callbackasm1(SB)
	MOV $61, X7
	JMP callbackasm1(SB)
	MOV $62, X7
	JMP callbackasm1(SB)
	MOV $63, X7
	JMP callbackasm1(SB)
	MOV $64, X7
	JMP callbackasm1(SB)
	MOV $65, X7
	JMP callbackasm1(SB)
	MOV $66, X7
	JMP callbackasm1(SB)
	MOV $67, X7
	JMP callbackasm1(SB)
	MOV $68, X7
	JMP callbackasm1(SB)
	MOV $69, X7
	JMP callbackasm1(SB)
	MOV $70, X7
	JMP callbackasm1(SB)
	MOV $71, X7
	JMP callbackasm1(SB)
	MOV $72, X7
	JMP callbackasm1(SB)
	MOV $73, X7
	JMP callbackasm1(SB)
	MOV $74, X7
	JMP callbackasm1(SB)
	MOV $75, X7
	JMP callbackasm1(SB)
	MOV $76, X7
	JMP callbackasm1(SB)
	MOV $77, X7
	JMP callbackasm1(SB)
	MOV $78, X7
	JMP callbackasm1(SB)
	MOV $79, X7
	JMP callbackasm1(SB)
	MOV $80, X7
	JMP callbackasm1(SB)
	MOV $81, X7
	JMP callbackasm1(SB)
	MOV $82, X7
	JMP callbackasm1(SB)
	MOV $83, X7
	JMP callbackasm1(SB)
	MOV $84, X7
	JMP callbackasm1(SB)
	MOV $85, X7
	JMP callbackasm1(SB)
	MOV $86, X7
	JMP callbackasm1(SB)
	MOV $87, X7
	JMP callbackasm1(SB)
	MOV $88, X7
	JMP callbackasm1(SB)
	MOV $89, X7
	JMP callbackasm1(SB)
	MOV $90, X7
	JMP callbackasm1(SB)
	MOV $91, X7
	JMP callbackasm1(SB)
	MOV $92, X7
	JMP callbackasm1(SB)
	MOV $93, X7
	JMP callbackasm1(SB)
	MOV $94, X7
	JMP callbackasm1(SB)
	MOV $95, X7
	JMP callbackasm1(SB)
	MOV $96, X7
	JMP callbackasm1(SB)
	MOV $97, X7
	JMP callbackasm1(SB)
	MOV $98, X7
	JMP callbackasm1(SB)
	MOV $99, X7
	JMP callbackasm1(SB)
	MOV $100, X7
	JMP callbackasm1(SB)
	MOV $101, X7
	JMP callbackasm1(SB)
	MOV $102, X7
	JMP callbackasm1(SB)
	MOV $103, X7
	JMP callbackasm1(SB)
	MOV $104, X7
	JMP callbackasm1(SB)
	MOV $105, X7
	JMP callbackasm1(SB)
	MOV $106, X7
	JMP callbackasm1(SB)
	MOV $107, X7
	JMP callbackasm1(SB)
	MOV $108, X7
	JMP callbackasm1(SB)
	MOV $109, X7
	JMP callbackasm1(SB)
	MOV $110, X7
	JMP callbackasm1(SB)
	MOV $111, X7
	JMP callbackasm1(SB)
	MOV $112, X7
	JMP callbackasm1(SB)
	MOV $113, X7
	JMP callbackasm1(SB)
	MOV $114, X7
	JMP callbackasm1(SB)
	MOV $115, X7
	JMP callbackasm1(SB)
	MOV $116, X7
	JMP callbackasm1(SB)
	MOV $117, X7
	JMP callbackasm1(SB)
	MOV $118, X7
	JMP callbackasm1(SB)
	MOV $119, X7
	JMP callbackasm1(SB)
	MOV $120, X7
	JMP callbackasm1(SB)
	MOV $121, X7
	JMP callbackasm1(SB)
	MOV $122, X7
	JMP callbackasm1(SB)
	MOV $123, X7
	JMP callbackasm1(SB)
	MOV $124, X7
	JMP callbackasm1(SB)
	MOV $125, X7
	JMP callbackasm1(SB)
	MOV $126, X7
	JMP callbackasm1(SB)
	MOV $127, X7
	JMP callbackasm1(SB)
	MOV $128, X7
	JMP callbackasm1(SB)
	MOV $129, X7
	JMP callbackasm1(SB)
	MOV $130, X7
	JMP callbackasm1(SB)
	MOV $131, X7
	JMP callbackasm1(SB)
	MOV $132, X7
	JMP callbackasm1(SB)
	MOV $133, X7
	JMP callbackasm1(SB)
	MOV $134, X7
	JMP callbackasm1(SB)
	MOV $135, X7
	JMP callbackasm1(SB)
	MOV $136, X7
	JMP callbackasm1(SB)
	MOV $137, X7
	JMP callbackasm1(SB)
	MOV $138, X7
	JMP callbackasm1(SB)
	MOV $139, X7
	JMP callbackasm1(SB)
	MOV $140, X7
	JMP callbackasm1(SB)
	MOV $141, X7
	JMP callbackasm1(SB)
	MOV $142, X7
	JMP callbackasm1(SB)
	MOV $143, X7
	JMP callbackasm1(SB)
	MOV $144, X7
	JMP callbackasm1(SB)
	MOV $145, X7
	JMP callbackasm1(SB)
	MOV $146, X7
	JMP callbackasm1(SB)
	MOV $147, X7
	JMP callbackasm1(SB)
	MOV $148, X7
	JMP callbackasm1(SB)
	MOV $149, X7
	JMP callbackasm1(SB)
	MOV $150, X7
	JMP callbackasm1(SB)
	MOV $151, X7
	JMP callbackasm1(SB)
	MOV $152, X7
	JMP callbackasm1(SB)
	MOV $153, X7
	JMP callbackasm1(SB)
	MOV $154, X7
	JMP callbackasm1(SB)
	MOV $155, X7
	JMP callbackasm1(SB)
	MOV $156, X7
	JMP callbackasm1(SB)
	MOV $157, X7
	JMP callbackasm1(SB)
	MOV $158, X7
	JMP callbackasm1(SB)
	MOV $159, X7
	JMP callbackasm1(SB)
	MOV $160, X7
	JMP callbackasm1(SB)
	MOV $161, X7
	JMP callbackasm1(SB)
	MOV $162, X7
	JMP callbackasm1(SB)
	MOV $163, X7
	JMP callbackasm1(SB)
	MOV $164, X7
	JMP callbackasm1(SB)
	MOV $165, X7
	JMP callbackasm1(SB)
	MOV $166, X7
	JMP callbackasm1(SB)
	MOV $167, X7
	JMP callbackasm1(SB)
	MOV $168, X7
	JMP callbackasm1(SB)
	MOV $169, X7
	JMP callbackasm1(SB)
	MOV $170, X7
	JMP callbackasm1(SB)
	MOV $171, X7
	JMP callbackasm1(SB)
	MOV $172, X7
	JMP callbackasm1(SB)
	MOV $173, X7
	JMP callbackasm1(SB)
	MOV $174, X7
	JMP callbackasm1(SB)
	MOV $175, X7
	JMP callbackasm1(SB)
	MOV $176, X7
	JMP callbackasm1(SB)
	MOV $177, X7
	JMP callbackasm1(SB)
	MOV $178, X7
	JMP callbackasm1(SB)
	MOV $179, X7
	JMP callbackasm1(SB)
	MOV $180, X7
	JMP callbackasm1(SB)
	MOV $181, X7
	JMP callbackasm1(SB)
	MOV $182, X7
	JMP callbackasm1(SB)
	MOV $183, X7
	JMP callbackasm1(SB)
	MOV $184, X7
	JMP callbackasm1(SB)
	MOV $185, X7
	JMP callbackasm1(SB)
	MOV $186, X7
	JMP callbackasm1(SB)
	MOV $187, X7
	JMP callbackasm1(SB)
	MOV $188, X7
	JMP callbackasm1(SB)
	MOV $189, X7
	JMP callbackasm1(SB)
	MOV $190, X7
	JMP callbackasm1(SB)
	MOV $191, X7
	JMP callbackasm1(SB)
	MOV $192, X7
	JMP callbackasm1(SB)
	MOV $193, X7
	JMP callbackasm1(SB)
	MOV $194, X7
	JMP callbackasm1(SB)
	MOV $195, X7
	JMP callbackasm1(SB)
	MOV $196, X7
	JMP callbackasm1(SB)
	MOV $197, X7
	JMP callbackasm1(SB)
	MOV $198, X7
	JMP callbackasm1(SB)
	MOV $199, X7
	JMP callbackasm1(SB)
	MOV $200, X7
	JMP callbackasm1(SB)
	MOV $201, X7
	JMP callbackasm1(SB)
	MOV $202, X7
	JMP callbackasm1(SB)
	MOV $203, X7
	JMP callbackasm1(SB)
	MOV $204, X7
	JMP callbackasm1(SB)
	MOV $205, X7
	JMP callbackasm1(SB)
	MOV $206, X7
	JMP callbackasm1(SB)
	MOV $207, X7
	JMP callbackasm1(SB)
	MOV $208, X7
	JMP callbackasm1(SB)
	MOV $209, X7
	JMP callbackasm1(SB)
	MOV $210, X7
	JMP callbackasm1(SB)
	MOV $211, X7
	JMP callbackasm1(SB)
	MOV $212, X7
	JMP callbackasm1(SB)
	MOV $213, X7
	JMP callbackasm1(SB)
	MOV $214, X7
	JMP callbackasm1(SB)
	MOV $215, X7
	JMP callbackasm1(SB)
	MOV $216, X7
	JMP callbackasm1(SB)
	MOV $217, X7
	JMP callbackasm1(SB)
	MOV $218, X7
	JMP callbackasm1(SB)
	MOV $219, X7
	JMP callbackasm1(SB)
	MOV $220, X7
	JMP callbackasm1(SB)
	MOV $221, X7
	JMP callbackasm1(SB)
	MOV $222, X7
	JMP callbackasm1(SB)
	MOV $223, X7
	JMP callbackasm1(SB)
	MOV $224, X7
	JMP callbackasm1(SB)
	MOV $225, X7
	JMP callbackasm1(SB)
	MOV $226, X7
	JMP callbackasm1(SB)
	MOV $227, X7
	JMP callbackasm1(SB)
	MOV $228, X7
	JMP callbackasm1(SB)
	MOV $229, X7
	JMP callbackasm1(SB)
	MOV $230, X7
	JMP callbackasm1(SB)
	MOV $231, X7
	JMP callbackasm1(SB)
	MOV $232, X7
	JMP callbackasm1(SB)
	MOV $233, X7
	JMP callbackasm1(SB)
	MOV $234, X7
	JMP callbackasm1(SB)
	MOV $235, X7
	JMP callbackasm1(SB)
	MOV $236, X7
	JMP callbackasm1(SB)
	MOV $237, X7
	JMP callbackasm1(SB)
	MOV $238, X7
	JMP callbackasm1(SB)
	MOV $239, X7
	JMP callbackasm1(SB)
	MOV $240, X7
	JMP callbackasm1(SB)
	MOV $241, X7
	JMP callbackasm1(SB)
	MOV $242, X7
	JMP callbackasm1(SB)
	MOV $243, X7
	JMP callbackasm1(SB)
	MOV $244, X7
	JMP callbackasm1(SB)
	MOV $245, X7
	JMP callbackasm1(SB)
	MOV $246, X7
	JMP callbackasm1(SB)
	MOV $247, X7
	JMP callbackasm1(SB)
	MOV $248, X7
	JMP callbackasm1(SB)
	MOV $249, X7
	JMP callbackasm1(SB)
	MOV $250, X7
	JMP callbackasm1(SB)
	MOV $251, X7
	JMP callbackasm1(SB)
	MOV $252, X7
	JMP callbackasm1(SB)
	MOV $253, X7
	JMP callbackasm1(SB)
	MOV $254, X7
	JMP callbackasm1(SB)
	MOV $255, X7
	JMP callbackasm1(SB)
	MOV $256, X7
	JMP callbackasm1(SB)
	MOV $257, X7
	JMP callbackasm1(SB)
	MOV $258, X7
	JMP callbackasm1(SB)
	MOV $259, X7
	JMP callbackasm1(SB)
	MOV $260, X7
	JMP callbackasm1(SB)
	MOV $261, X7
	JMP callbackasm1(SB)
	MOV $262, X7
	JMP callbackasm1(SB)
	MOV $263, X7
	JMP callbackasm1(SB)
	MOV $264, X7
	JMP callbackasm1(SB)
	MOV $265, X7
	JMP callbackasm1(SB)
	MOV $266, X7
	JMP callbackasm1(SB)
	MOV $267, X7
	JMP callbackasm1(SB)
	MOV $268, X7
	JMP callbackasm1(SB)
	MOV $269, X7
	JMP callbackasm1(SB)
	MOV $270, X7
	JMP callbackasm1(SB)
	MOV $271, X7
	JMP callbackasm1(SB)
	MOV $272, X7
	JMP callbackasm1(SB)
	MOV $273, X7
	JMP callbackasm1(SB)
	MOV $274, X7
	JMP callbackasm1(SB)
	MOV $275, X7
	JMP callbackasm1(SB)
	MOV $276, X7
	JMP callbackasm1(SB)
	MOV $277, X7
	JMP callbackasm1(SB)
	MOV $278, X7
	JMP callbackasm1(SB)
	MOV $279, X7
	JMP callbackasm1(SB)
	MOV $280, X7
	JMP callbackasm1(SB)
	MOV $281, X7
	JMP callbackasm1(SB)
	MOV $282, X7
	JMP callbackasm1(SB)
	MOV $283, X7
	JMP callbackasm1(SB)
	MOV $284, X7
	JMP callbackasm1(SB)
	MOV $285, X7
	JMP callbackasm1(SB)
	MOV $286, X7
	JMP callbackasm1(SB)
	MOV $287, X7
	JMP callbackasm1(SB)
	MOV $288, X7
	JMP callbackasm1(SB)
	MOV $289, X7
	JMP callbackasm1(SB)
	MOV $290, X7
	JMP callbackasm1(SB)
	MOV $291, X7
	JMP callbackasm1(SB)
	MOV $292, X7
	JMP callbackasm1(SB)
	MOV $293, X7
	JMP callbackasm1(SB)
	MOV $294, X7
	JMP callbackasm1(SB)
	MOV $295, X7
	JMP callbackasm1(SB)
	MOV $296, X7
	JMP callbackasm1(SB)
	MOV $297, X7
	JMP callbackasm1(SB)
	MOV $298, X7
	JMP callbackasm1(SB)
	MOV $299, X7
	JMP callbackasm1(SB)
	MOV $300, X7
	JMP callbackasm1(SB)
	MOV $301, X7
	JMP callbackasm1(SB)
	MOV $302, X7
	JMP callbackasm1(SB)
	MOV $303, X7
	JMP callbackasm1(SB)
	MOV $304, X7
	JMP callbackasm1(SB)
	MOV $305, X7
	JMP callbackasm1(SB)
	MOV $306, X7
	JMP callbackasm1(SB)
	MOV $307, X7
	JMP callbackasm1(SB)
	MOV $308, X7
	JMP callbackasm1(SB)
	MOV $309, X7
	JMP callbackasm1(SB)
	MOV $310, X7
	JMP callbackasm1(SB)
	MOV $311, X7
	JMP callbackasm1(SB)
	MOV $312, X7
	JMP callbackasm1(SB)
	MOV $313, X7
	JMP callbackasm1(SB)
	MOV $314, X7
	JMP callbackasm1(SB)
	MOV $315, X7
	JMP callbackasm1(SB)
	MOV $316, X7
	JMP callbackasm1(SB)
	MOV $317, X7
	JMP callbackasm1(SB)
	MOV $318, X7
	JMP callbackasm1(SB)
	MOV $319, X7
	JMP callbackasm1(SB)
	MOV $320, X7
	JMP callbackasm1(SB)
	MOV $321, X7
	JMP callbackasm1(SB)
	MOV $322, X7
	JMP callbackasm1(SB)
	MOV $323, X7
	JMP callbackasm1(SB)
	MOV $324, X7
	JMP callbackasm1(SB)
	MOV $325, X7
	JMP callbackasm1(SB)
	MOV $326, X7
	JMP callbackasm1(SB)
	MOV $327, X7
	JMP callbackasm1(SB)
	MOV $328, X7
	JMP callbackasm1(SB)
	MOV $329, X7
	JMP callbackasm1(SB)
	MOV $330, X7
	JMP callbackasm1(SB)
	MOV $331, X7
	JMP callbackasm1(SB)
	MOV $332, X7
	JMP callbackasm1(SB)
	MOV $333, X7
	JMP callbackasm1(SB)
	MOV $334, X7
	JMP callbackasm1(SB)
	MOV $335, X7
	JMP callbackasm1(SB)
	MOV $336, X7
	JMP callbackasm1(SB)
	MOV $337, X7
	JMP callbackasm1(SB)
	MOV $338, X7
	JMP callbackasm1(SB)
	MOV $339, X7
	JMP callbackasm1(SB)
	MOV $340, X7
	JMP callbackasm1(SB)
	MOV $341, X7
	JMP callbackasm1(SB)
	MOV $342, X7
	JMP callbackasm1(SB)
	MOV $343, X7
	JMP callbackasm1(SB)
	MOV $344, X7
	JMP callbackasm1(SB)
	MOV $345, X7
	JMP callbackasm1(SB)
	MOV $346, X7
	JMP callbackasm1(SB)
	MOV $347, X7
	JMP callbackasm1(SB)
	MOV $348, X7
	JMP callbackasm1(SB)
	MOV $349, X7
	JMP callbackasm1(SB)
	MOV $350, X7
	JMP callbackasm1(SB)
	MOV $351, X7
	JMP callbackasm1(SB)
	MOV $352, X7
	JMP callbackasm1(SB)
	MOV $353, X7
	JMP callbackasm1(SB)
	MOV $354, X7
	JMP callbackasm1(SB)
	MOV $355, X7
	JMP callbackasm1(SB)
	MOV $356, X7
	JMP callbackasm1(SB)
	MOV $357, X7
	JMP callbackasm1(SB)
	MOV $358, X7
	JMP callbackasm1(SB)
	MOV $359, X7
	JMP callbackasm1(SB)
	MOV $360, X7
	JMP callbackasm1(SB)
	MOV $361, X7
	JMP callbackasm1(SB)
	MOV $362, X7
	JMP callbackasm1(SB)
	MOV $363, X7
	JMP callbackasm1(SB)
	MOV $364, X7
	JMP callbackasm1(SB)
	MOV $365, X7
	JMP callbackasm1(SB)
	MOV $366, X7
	JMP callbackasm1(SB)
	MOV $367, X7
	JMP callbackasm1(SB)
	MOV $368, X7
	JMP callbackasm1(SB)
	MOV $369, X7
	JMP callbackasm1(SB)
	MOV $370, X7
	JMP callbackasm1(SB)
	MOV $371, X7
	JMP callbackasm1(SB)
	MOV $372, X7
	JMP callbackasm1(SB)
	MOV $373, X7
	JMP callbackasm1(SB)
	MOV $374, X7
	JMP callbackasm1(SB)
	MOV $375, X7
	JMP callbackasm1(SB)
	MOV $376, X7
	JMP callbackasm1(SB)
	MOV $377, X7
	JMP callbackasm1(SB)
	MOV $378, X7
	JMP callbackasm1(SB)
	MOV $379, X7
	JMP callbackasm1(SB)
	MOV $380, X7
	JMP callbackasm1(SB)
	MOV $381, X7
	JMP callbackasm1(SB)
	MOV $382, X7
	JMP callbackasm1(SB)
	MOV $383, X7
	JMP callbackasm1(SB)
	MOV $384, X7
	JMP callbackasm1(SB)
	MOV $385, X7
	JMP callbackasm1(SB)
	MOV $386, X7
	JMP callbackasm1(SB)
	MOV $387, X7
	JMP callbackasm1(SB)
	MOV $388, X7
	JMP callbackasm1(SB)
	MOV $389, X7
	JMP callbackasm1(SB)
	MOV $390, X7
	JMP callbackasm1(SB)
	MOV $391, X7
	JMP callbackasm1(SB)
	MOV $392, X7
	JMP callbackasm1(SB)
	MOV $393, X7
	JMP callbackasm1(SB)
	MOV $394, X7
	JMP callbackasm1(SB)
	MOV $395, X7
	JMP callbackasm1(SB)
	MOV $396, X7
	JMP callbackasm1(SB)
	MOV $397, X7
	JMP callbackasm1(SB)
	MOV $398, X7
	JMP callbackasm1(SB)
	MOV $399, X7
	JMP callbackasm1(SB)
	MOV $400, X7
	JMP callbackasm1(SB)
	MOV $401, X7
	JMP callbackasm1(SB)
	MOV $402, X7
	JMP callbackasm1(SB)
	MOV $403, X7
	JMP callbackasm1(SB)
	MOV $404, X7
	JMP callbackasm1(SB)
	MOV $405, X7
	JMP callbackasm1(SB)
	MOV $406, X7
	JMP callbackasm1(SB)
	MOV $407, X7
	JMP callbackasm1(SB)
	MOV $408, X7
	JMP callbackasm1(SB)
	MOV $409, X7
	JMP callbackasm1(SB)
	MOV $410, X7
	JMP callbackasm1(SB)
	MOV $411, X7
	JMP callbackasm1(SB)
	MOV $412, X7
	JMP callbackasm1(SB)
	MOV $413, X7
	JMP callbackasm1(SB)
	MOV $414, X7
	JMP callbackasm1(SB)
	MOV $415, X7
	JMP callbackasm1(SB)
	MOV $416, X7
	JMP callbackasm1(SB)
	MOV $417, X7
	JMP callbackasm1(SB)
	MOV $418, X7
	JMP callbackasm1(SB)
	MOV $419, X7
	JMP callbackasm1(SB)
	MOV $420, X7
	JMP callbackasm1(SB)
	MOV $421, X7
	JMP callbackasm1(SB)
	MOV $422, X7
	JMP callbackasm1(SB)
	MOV $423, X7
	JMP callbackasm1(SB)
	MOV $424, X7
	JMP callbackasm1(SB)
	MOV $425, X7
	JMP callbackasm1(SB)
	MOV $426, X7
	JMP callbackasm1(SB)
	MOV $427, X7
	JMP callbackasm1(SB)
	MOV $428, X7
	JMP callbackasm1(SB)
	MOV $429, X7
	JMP callbackasm1(SB)
	MOV $430, X7
	JMP callbackasm1(SB)
	MOV $431, X7
	JMP callbackasm1(SB)
	MOV $432, X7
	JMP callbackasm1(SB)
	MOV $433, X7
	JMP callbackasm1(SB)
	MOV $434, X7
	JMP callbackasm1(SB)
	MOV $435, X7
	JMP callbackasm1(SB)
	MOV $436, X7
	JMP callbackasm1(SB)
	MOV $437, X7
	JMP callbackasm1(SB)
	MOV $438, X7
	JMP callbackasm1(SB)
	MOV $439, X7
	JMP callbackasm1(SB)
	MOV $440, X7
	JMP callbackasm1(SB)
	MOV $441, X7
	JMP callbackasm1(SB)
	MOV $442, X7
	JMP callbackasm1(SB)
	MOV $443, X7
	JMP callbackasm1(SB)
	MOV $444, X7
	JMP callbackasm1(SB)
	MOV $445, X7
	JMP callbackasm1(SB)
	MOV $446, X7
	JMP callbackasm1(SB)
	MOV $447, X7
	JMP callbackasm1(SB)
	MOV $448, X7
	JMP callbackasm1(SB)
	MOV $449, X7
	JMP callbackasm1(SB)
	MOV $450, X7
	JMP callbackasm1(SB)
	MOV $451, X7
	JMP callbackasm1(SB)
	MOV $452, X7
	JMP callbackasm1(SB)
	MOV $453, X7
	JMP callbackasm1(SB)
	MOV $454, X7
	JMP callbackasm1(SB)
	MOV $455, X7
	JMP callbackasm1(SB)
	MOV $456, X7
	JMP callbackasm1(SB)
	MOV $457, X7
	JMP callbackasm1(SB)
	MOV $458, X7
	JMP callbackasm1(SB)
	MOV $459, X7
	JMP callbackasm1(SB)
	MOV $460, X7
	JMP callbackasm1(SB)
	MOV $461, X7
	JMP callbackasm1(SB)
	MOV $462, X7
	JMP callbackasm1(SB)
	MOV $463, X7
	JMP callbackasm1(SB)
	MOV $464, X7
	JMP callbackasm1(SB)
	MOV $465, X7
	JMP callbackasm1(SB)
	MOV $466, X7
	JMP callbackasm1(SB)
	MOV $467, X7
	JMP callbackasm1(SB)
	MOV $468, X7
	JMP callbackasm1(SB)
	MOV $469, X7
	JMP callbackasm1(SB)
	MOV $470, X7
	JMP callbackasm1(SB)
	MOV $471, X7
	JMP callbackasm1(SB)
	MOV $472, X7
	JMP callbackasm1(SB)
	MOV $473, X7
	JMP callbackasm1(SB)
	MOV $474, X7
	JMP callbackasm1(SB)
	MOV $475, X7
	JMP callbackasm1(SB)
	MOV $476, X7
	JMP callbackasm1(SB)
	MOV $477, X7
	JMP callbackasm1(SB)
	MOV $478, X7
	JMP callbackasm1(SB)
	MOV $479, X7
	JMP callbackasm1(SB)
	MOV $480, X7
	JMP callbackasm1(SB)
	MOV $481, X7
	JMP callbackasm1(SB)
	MOV $482, X7
	JMP callbackasm1(SB)
	MOV $483, X7
	JMP callbackasm1(SB)
	MOV $484, X7
	JMP callbackasm1(SB)
	MOV $485, X7
	JMP callbackasm1(SB)
	MOV $486, X7
	JMP callbackasm1(SB)
	MOV $487, X7
	JMP callbackasm1(SB)
	MOV $488, X7
	JMP callbackasm1(SB)
	MOV $489, X7
	JMP callbackasm1(SB)
	MOV $490, X7
	JMP callbackasm1(SB)
	MOV $491, X7
	JMP callbackasm1(SB)
	MOV $492, X7
	JMP callbackasm1(SB)
	MOV $493, X7
	JMP callbackasm1(SB)
	MOV $494, X7
	JMP callbackasm1(SB)
	MOV $495, X7
	JMP callbackasm1(SB)
	MOV $496, X7
	JMP callbackasm1(SB)
	MOV $497, X7
	JMP callbackasm1(SB)
	MOV $498, X7
	JMP callbackasm1(SB)
	MOV $499, X7
	JMP callbackasm1(SB)
	MOV $500, X7
	JMP callbackasm1(SB)
	MOV $501, X7
	JMP callbackasm1(SB)
	MOV $502, X7
	JMP callbackasm1(SB)
	MOV $503, X7
	JMP callbackasm1(SB)
	MOV $504, X7
	JMP callbackasm1(SB)
	MOV $505, X7
	JMP callbackasm1(SB)
	MOV $506, X7
	JMP callbackasm1(SB)
	MOV $507, X7
	JMP callbackasm1(SB)
	MOV $508, X7
	JMP callbackasm1(SB)
	MOV $509, X7
	JMP callbackasm1(SB)
	MOV $510, X7
	JMP callbackasm1(SB)
	MOV $511, X7
	JMP callbackasm1(SB)
	MOV $512, X7
	JMP callbackasm1(SB)
	MOV $513, X7
	JMP callbackasm1(SB)
	MOV $514, X7
	JMP callbackasm1(SB)
	MOV $515, X7
	JMP callbackasm1(SB)
	MOV $516, X7
	JMP callbackasm1(SB)
	MOV $517, X7
	JMP callbackasm1(SB)
	MOV $518, X7
	JMP callbackasm1(SB)
	MOV $519, X7
	JMP callbackasm1(SB)
	MOV $520, X7
	JMP callbackasm1(SB)
	MOV $521, X7
	JMP callbackasm1(SB)
	MOV $522, X7
	JMP callbackasm1(SB)
	MOV $523, X7
	JMP callbackasm1(SB)
	MOV $524, X7
	JMP callbackasm1(SB)
	MOV $525, X7
	JMP callbackasm1(SB)
	MOV $526, X7
	JMP callbackasm1(SB)
	MOV $527, X7
	JMP callbackasm1(SB)
	MOV $528, X7
	JMP callbackasm1(SB)
	MOV $529, X7
	JMP callbackasm1(SB)
	MOV $530, X7
	JMP callbackasm1(SB)
	MOV $531, X7
	JMP callbackasm1(SB)
	MOV $532, X7
	JMP callbackasm1(SB)
	MOV $533, X7
	JMP callbackasm1(SB)
	MOV $534, X7
	JMP callbackasm1(SB)
	MOV $535, X7
	JMP callbackasm1(SB)
	MOV $536, X7
	JMP callbackasm1(SB)
	MOV $537, X7
	JMP callbackasm1(SB)
	MOV $538, X7
	JMP callbackasm1(SB)
	MOV $539, X7
	JMP callbackasm1(SB)
	MOV $540, X7
	JMP callbackasm1(SB)
	MOV $541, X7
	JMP callbackasm1(SB)
	MOV $542, X7
	JMP callbackasm1(SB)
	MOV $543, X7
	JMP callbackasm1(SB)
	MOV $544, X7
	JMP callbackasm1(SB)
	MOV $545, X7
	JMP callbackasm1(SB)
	MOV $546, X7
	JMP callbackasm1(SB)
	MOV $547, X7
	JMP callbackasm1(SB)
	MOV $548, X7
	JMP callbackasm1(SB)
	MOV $549, X7
	JMP callbackasm1(SB)
	MOV $550, X7
	JMP callbackasm1(SB)
	MOV $551, X7
	JMP callbackasm1(SB)
	MOV $552, X7
	JMP callbackasm1(SB)
	MOV $553, X7
	JMP callbackasm1(SB)
	MOV $554, X7
	JMP callbackasm1(SB)
	MOV $555, X7
	JMP callbackasm1(SB)
	MOV $556, X7
	JMP callbackasm1(SB)
	MOV $557, X7
	JMP callbackasm1(SB)
	MOV $558, X7
	JMP callbackasm1(SB)
	MOV $559, X7
	JMP callbackasm1(SB)
	MOV $560, X7
	JMP callbackasm1(SB)
	MOV $561, X7
	JMP callbackasm1(SB)
	MOV $562, X7
	JMP callbackasm1(SB)
	MOV $563, X7
	JMP callbackasm1(SB)
	MOV $564, X7
	JMP callbackasm1(SB)
	MOV $565, X7
	JMP callbackasm1(SB)
	MOV $566, X7
	JMP callbackasm1(SB)
	MOV $567, X7
	JMP callbackasm1(SB)
	MOV $568, X7
	JMP callbackasm1(SB)
	MOV $569, X7
	JMP callbackasm1(SB)
	MOV $570, X7
	JMP callbackasm1(SB)
	MOV $571, X7
	JMP callbackasm1(SB)
	MOV $572, X7
	JMP callbackasm1(SB)
	MOV $573, X7
	JMP callbackasm1(SB)
	MOV $574, X7
	JMP callbackasm1(SB)
	MOV $575, X7
	JMP callbackasm1(SB)
	MOV $576, X7
	JMP callbackasm1(SB)
	MOV $577, X7
	JMP callbackasm1(SB)
	MOV $578, X7
	JMP callbackasm1(SB)
	MOV $579, X7
	JMP callbackasm1(SB)
	MOV $580, X7
	JMP callbackasm1(SB)
	MOV $581, X7
	JMP callbackasm1(SB)
	MOV $582, X7
	JMP callbackasm1(SB)
	MOV $583, X7
	JMP callbackasm1(SB)
	MOV $584, X7
	JMP callbackasm1(SB)
	MOV $585, X7
	JMP callbackasm1(SB)
	MOV $586, X7
	JMP callbackasm1(SB)
	MOV $587, X7
	JMP callbackasm1(SB)
	MOV $588, X7
	JMP callbackasm1(SB)
	MOV $589, X7
	JMP callbackasm1(SB)
	MOV $590, X7
	JMP callbackasm1(SB)
	MOV $591, X7
	JMP callbackasm1(SB)
	MOV $592, X7
	JMP callbackasm1(SB)
	MOV $593, X7
	JMP callbackasm1(SB)
	MOV $594, X7
	JMP callbackasm1(SB)
	MOV $595, X7
	JMP callbackasm1(SB)
	MOV $596, X7
	JMP callbackasm1(SB)
	MOV $597, X7
	JMP callbackasm1(SB)
	MOV $598, X7
	JMP callbackasm1(SB)
	MOV $599, X7
	JMP callbackasm1(SB)
	MOV $600, X7
	JMP callbackasm1(SB)
	MOV $601, X7
	JMP callbackasm1(SB)
	MOV $602, X7
	JMP callbackasm1(SB)
	MOV $603, X7
	JMP callbackasm1(SB)
	MOV $604, X7
	JMP callbackasm1(SB)
	MOV $605, X7
	JMP callbackasm1(SB)
	MOV $606, X7
	JMP callbackasm1(SB)
	MOV $607, X7
	JMP callbackasm1(SB)
	MOV $608, X7
	JMP callbackasm1(SB)
	MOV $609, X7
	JMP callbackasm1(SB)
	MOV $610, X7
	JMP callbackasm1(SB)
	MOV $611, X7
	JMP callbackasm1(SB)
	MOV $612, X7
	JMP callbackasm1(SB)
	MOV $613, X7
	JMP callbackasm1(SB)
	MOV $614, X7
	JMP callbackasm1(SB)
	MOV $615, X7
	JMP callbackasm1(SB)
	MOV $616, X7
	JMP callbackasm1(SB)
	MOV $617, X7
	JMP callbackasm1(SB)
	MOV $618, X7
	JMP callbackasm1(SB)
	MOV $619, X7
	JMP callbackasm1(SB)
	MOV $620, X7
	JMP callbackasm1(SB)
	MOV $621, X7
	JMP callbackasm1(SB)
	MOV $622, X7
	JMP callbackasm1(SB)
	MOV $623, X7
	JMP callbackasm1(SB)
	MOV $624, X7
	JMP callbackasm1(SB)
	MOV $625, X7
	JMP callbackasm1(SB)
	MOV $626, X7
	JMP callbackasm1(SB)
	MOV $627, X7
	JMP callbackasm1(SB)
	MOV $628, X7
	JMP callbackasm1(SB)
	MOV $629, X7
	JMP callbackasm1(SB)
	MOV $630, X7
	JMP callbackasm1(SB)
	MOV $631, X7
	JMP callbackasm1(SB)
	MOV $632, X7
	JMP callbackasm1(SB)
	MOV $633, X7
	JMP callbackasm1(SB)
	MOV $634, X7
	JMP callbackasm1(SB)
	MOV $635, X7
	JMP callbackasm1(SB)
	MOV $636, X7
	JMP callbackasm1(SB)
	MOV $637, X7
	JMP callbackasm1(SB)
	MOV $638, X7
	JMP callbackasm1(SB)
	MOV $639, X7
	JMP callbackasm1(SB)
	MOV $640, X7
	JMP callbackasm1(SB)
	MOV $641, X7
	JMP callbackasm1(SB)
	MOV $642, X7
	JMP callbackasm1(SB)
	MOV $643, X7
	JMP callbackasm1(SB)
	MOV $644, X7
	JMP callbackasm1(SB)
	MOV $645, X7
	JMP callbackasm1(SB)
	MOV $646, X7
	JMP callbackasm1(SB)
	MOV $647, X7
	JMP callbackasm1(SB)
	MOV $648, X7
	JMP callbackasm1(SB)
	MOV $649, X7
	JMP callbackasm1(SB)
	MOV $650, X7
	JMP callbackasm1(SB)
	MOV $651, X7
	JMP callbackasm1(SB)
	MOV $652, X7
	JMP callbackasm1(SB)
	MOV $653, X7
	JMP callbackasm1(SB)
	MOV $654, X7
	JMP callbackasm1(SB)
	MOV $655, X7
	JMP callbackasm1(SB)
	MOV $656, X7
	JMP callbackasm1(SB)
	MOV $657, X7
	JMP callbackasm1(SB)
	MOV $658, X7
	JMP callbackasm1(SB)
	MOV $659, X7
	JMP callbackasm1(SB)
	MOV $660, X7
	JMP callbackasm1(SB)
	MOV $661, X7
	JMP callbackasm1(SB)
	MOV $662, X7
	JMP callbackasm1(SB)
	MOV $663, X7
	JMP callbackasm1(SB)
	MOV $664, X7
	JMP callbackasm1(SB)
	MOV $665, X7
	JMP callbackasm1(SB)
	MOV $666, X7
	JMP callbackasm1(SB)
	MOV $667, X7
	JMP callbackasm1(SB)
	MOV $668, X7
	JMP callbackasm1(SB)
	MOV $669, X7
	JMP callbackasm1(SB)
	MOV $670, X7
	JMP callbackasm1(SB)
	MOV $671, X7
	JMP callbackasm1(SB)
	MOV $672, X7
	JMP callbackasm1(SB)
	MOV $673, X7
	JMP callbackasm1(SB)
	MOV $674, X7
	JMP callbackasm1(SB)
	MOV $675, X7
	JMP callbackasm1(SB)
	MOV $676, X7
	JMP callbackasm1(SB)
	MOV $677, X7
	JMP callbackasm1(SB)
	MOV $678, X7
	JMP callbackasm1(SB)
	MOV $679, X7
	JMP callbackasm1(SB)
	MOV $680, X7
	JMP callbackasm1(SB)
	MOV $681, X7
	JMP callbackasm1(SB)
	MOV $682, X7
	JMP callbackasm1(SB)
	MOV $683, X7
	JMP callbackasm1(SB)
	MOV $684, X7
	JMP callbackasm1(SB)
	MOV $685, X7
	JMP callbackasm1(SB)
	MOV $686, X7
	JMP callbackasm1(SB)
	MOV $687, X7
	JMP callbackasm1(SB)
	MOV $688, X7
	JMP callbackasm1(SB)
	MOV $689, X7
	JMP callbackasm1(SB)
	MOV $690, X7
	JMP callbackasm1(SB)
	MOV $691, X7
	JMP callbackasm1(SB)
	MOV $692, X7
	JMP callbackasm1(SB)
	MOV $693, X7
	JMP callbackasm1(SB)
	MOV $694, X7
	JMP callbackasm1(SB)
	MOV $695, X7
	JMP callbackasm1(SB)
	MOV $696, X7
	JMP callbackasm1(SB)
	MOV $697, X7
	JMP callbackasm1(SB)
	MOV $698, X7
	JMP callbackasm1(SB)
	MOV $699, X7
	JMP callbackasm1(SB)
	MOV $700, X7
	JMP callbackasm1(SB)
	MOV $701, X7
	JMP callbackasm1(SB)
	MOV $702, X7
	JMP callbackasm1(SB)
	MOV $703, X7
	JMP callbackasm1(SB)
	MOV $704, X7
	JMP callbackasm1(SB)
	MOV $705, X7
	JMP callbackasm1(SB)
	MOV $706, X7
	JMP callbackasm1(SB)
	MOV $707, X7
	JMP callbackasm1(SB)
	MOV $708, X7
	JMP callbackasm1(SB)
	MOV $709, X7
	JMP callbackasm1(SB)
	MOV $710, X7
	JMP callbackasm1(SB)
	MOV $711, X7
	JMP callbackasm1(SB)
	MOV $712, X7
	JMP callbackasm1(SB)
	MOV $713, X7
	JMP callbackasm1(SB)
	MOV $714, X7
	JMP callbackasm1(SB)
	MOV $715, X7
	JMP callbackasm1(SB)
	MOV $716, X7
	JMP callbackasm1(SB)
	MOV $717, X7
	JMP callbackasm1(SB)
	MOV $718, X7
	JMP callbackasm1(SB)
	MOV $719, X7
	JMP callbackasm1(SB)
	MOV $720, X7
	JMP callbackasm1(SB)
	MOV $721, X7
	JMP callbackasm1(SB)
	MOV $722, X7
	JMP callbackasm1(SB)
	MOV $723, X7
	JMP callbackasm1(SB)
	MOV $724, X7
	JMP callbackasm1(SB)
	MOV $725, X7
	JMP callbackasm1(SB)
	MOV $726, X7
	JMP callbackasm1(SB)
	MOV $727, X7
	JMP callbackasm1(SB)
	MOV $728, X7
	JMP callbackasm1(SB)
	MOV $729, X7
	JMP callbackasm1(SB)
	MOV $730, X7
	JMP callbackasm1(SB)
	MOV $731, X7
	JMP callbackasm1(SB)
	MOV $732, X7
	JMP callbackasm1(SB)
	MOV $733, X7
	JMP callbackasm1(SB)
	MOV $734, X7
	JMP callbackasm1(SB)
	MOV $735, X7
	JMP callbackasm1(SB)
	MOV $736, X7
	JMP callbackasm1(SB)
	MOV $737, X7
	JMP callbackasm1(SB)
	MOV $738, X7
	JMP callbackasm1(SB)
	MOV $739, X7
	JMP callbackasm1(SB)
	MOV $740, X7
	JMP callbackasm1(SB)
	MOV $741, X7
	JMP callbackasm1(SB)
	MOV $742, X7
	JMP callbackasm1(SB)
	MOV $743, X7
	JMP callbackasm1(SB)
	MOV $744, X7
	JMP callbackasm1(SB)
	MOV $745, X7
	JMP callbackasm1(SB)
	MOV $746, X7
	JMP callbackasm1(SB)
	MOV $747, X7
	JMP callbackasm1(SB)
	MOV $748, X7
	JMP callbackasm1(SB)
	MOV $749, X7
	JMP callbackasm1(SB)
	MOV $750, X7
	JMP callbackasm1(SB)
	MOV $751, X7
	JMP callbackasm1(SB)
	MOV $752, X7
	JMP callbackasm1(SB)
	MOV $753, X7
	JMP callbackasm1(SB)
	MOV $754, X7
	JMP callbackasm1(SB)
	MOV $755, X7
	JMP callbackasm1(SB)
	MOV $756, X7
	JMP callbackasm1(SB)
	MOV $757, X7
	JMP callbackasm1(SB)
	MOV $758, X7
	JMP callbackasm1(SB)
	MOV $759, X7
	JMP callbackasm1(SB)
	MOV $760, X7
	JMP callbackasm1(SB)
	MOV $761, X7
	JMP callbackasm1(SB)
	MOV $762, X7
	JMP callbackasm1(SB)
	MOV $763, X7
	JMP callbackasm1(SB)
	MOV $764, X7
	JMP callbackasm1(SB)
	MOV $765, X7
	JMP callbackasm1(SB)
	MOV $766, X7
	JMP callbackasm1(SB)
	MOV $767, X7
	JMP callbackasm1(SB)
	MOV $768, X7
	JMP callbackasm1(SB)
	MOV $769, X7
	JMP callbackasm1(SB)
	MOV $770, X7
	JMP callbackasm1(SB)
	MOV $771, X7
	JMP callbackasm1(SB)
	MOV $772, X7
	JMP callbackasm1(SB)
	MOV $773, X7
	JMP callbackasm1(SB)
	MOV $774, X7
	JMP callbackasm1(SB)
	MOV $775, X7
	JMP callbackasm1(SB)
	MOV $776, X7
	JMP callbackasm1(SB)
	MOV $777, X7
	JMP callbackasm1(SB)
	MOV $778, X7
	JMP callbackasm1(SB)
	MOV $779, X7
	JMP callbackasm1(SB)
	MOV $780, X7
	JMP callbackasm1(SB)
	MOV $781, X7
	JMP callbackasm1(SB)
	MOV $782, X7
	JMP callbackasm1(SB)
	MOV $783, X7
	JMP callbackasm1(SB)
	MOV $784, X7
	JMP callbackasm1(SB)
	MOV $785, X7
	JMP callbackasm1(SB)
	MOV $786, X7
	JMP callbackasm1(SB)
	MOV $787, X7
	JMP callbackasm1(SB)
	MOV $788, X7
	JMP callbackasm1(SB)
	MOV $789, X7
	JMP callbackasm1(SB)
	MOV $790, X7
	JMP callbackasm1(SB)
	MOV $791, X7
	JMP callbackasm1(SB)
	MOV $792, X7
	JMP callbackasm1(SB)
	MOV $793, X7
	JMP callbackasm1(SB)
	MOV $794, X7
	JMP callbackasm1(SB)
	MOV $795, X7
	JMP callbackasm1(SB)
	MOV $796, X7
	JMP callbackasm1(SB)
	MOV $797, X7
	JMP callbackasm1(SB)
	MOV $798, X7
	JMP callbackasm1(SB)
	MOV $799, X7
	JMP callbackasm1(SB)
	MOV $800, X7
	JMP callbackasm1(SB)
	MOV $801, X7
	JMP callbackasm1(SB)
	MOV $802, X7
	JMP callbackasm1(SB)
	MOV $803, X7
	JMP callbackasm1(SB)
	MOV $804, X7
	JMP callbackasm1(SB)
	MOV $805, X7
	JMP callbackasm1(SB)
	MOV $806, X7
	JMP callbackasm1(SB)
	MOV $807, X7
	JMP callbackasm1(SB)
	MOV $808, X7
	JMP callbackasm1(SB)
	MOV $809, X7
	JMP callbackasm1(SB)
	MOV $810, X7
	JMP callbackasm1(SB)
	MOV $811, X7
	JMP callbackasm1(SB)
	MOV $812, X7
	JMP callbackasm1(SB)
	MOV $813, X7
	JMP callbackasm1(SB)
	MOV $814, X7
	JMP callbackasm1(SB)
	MOV $815, X7
	JMP callbackasm1(SB)
	MOV $816, X7
	JMP callbackasm1(SB)
	MOV $817, X7
	JMP callbackasm1(SB)
	MOV $818, X7
	JMP callbackasm1(SB)
	MOV $819, X7
	JMP callbackasm1(SB)
	MOV $820, X7
	JMP callbackasm1(SB)
	MOV $821, X7
	JMP callbackasm1(SB)
	MOV $822, X7
	JMP callbackasm1(SB)
	MOV $823, X7
	JMP callbackasm1(SB)
	MOV $824, X7
	JMP callbackasm1(SB)
	MOV $825, X7
	JMP callbackasm1(SB)
	MOV $826, X7
	JMP callbackasm1(SB)
	MOV $827, X7
	JMP callbackasm1(SB)
	MOV $828, X7
	JMP callbackasm1(SB)
	MOV $829, X7
	JMP callbackasm1(SB)
	MOV $830, X7
	JMP callbackasm1(SB)
	MOV $831, X7
	JMP callbackasm1(SB)
	MOV $832, X7
	JMP callbackasm1(SB)
	MOV $833, X7
	JMP callbackasm1(SB)
	MOV $834, X7
	JMP callbackasm1(SB)
	MOV $835, X7
	JMP callbackasm1(SB)
	MOV $836, X7
	JMP callbackasm1(SB)
	MOV $837, X7
	JMP callbackasm1(SB)
	MOV $838, X7
	JMP callbackasm1(SB)
	MOV $839, X7
	JMP callbackasm1(SB)
	MOV $840, X7
	JMP callbackasm1(SB)
	MOV $841, X7
	JMP callbackasm1(SB)
	MOV $842, X7
	JMP callbackasm1(SB)
	MOV $843, X7
	JMP callbackasm1(SB)
	MOV $844, X7
	JMP callbackasm1(SB)
	MOV $845, X7
	JMP callbackasm1(SB)
	MOV $846, X7
	JMP callbackasm1(SB)
	MOV $847, X7
	JMP callbackasm1(SB)
	MOV $848, X7
	JMP callbackasm1(SB)
	MOV $849, X7
	JMP callbackasm1(SB)
	MOV $850, X7
	JMP callbackasm1(SB)
	MOV $851, X7
	JMP callbackasm1(SB)
	MOV $852, X7
	JMP callbackasm1(SB)
	MOV $853, X7
	JMP callbackasm1(SB)
	MOV $854, X7
	JMP callbackasm1(SB)
	MOV $855, X7
	JMP callbackasm1(SB)
	MOV $856, X7
	JMP callbackasm1(SB)
	MOV $857, X7
	JMP callbackasm1(SB)
	MOV $858, X7
	JMP callbackasm1(SB)
	MOV $859, X7
	JMP callbackasm1(SB)
	MOV $860, X7
	JMP callbackasm1(SB)
	MOV $861, X7
	JMP callbackasm1(SB)
	MOV $862, X7
	JMP callbackasm1(SB)
	MOV $863, X7
	JMP callbackasm1(SB)
	MOV $864, X7
	JMP callbackasm1(SB)
	MOV $865, X7
	JMP callbackasm1(SB)
	MOV $866, X7
	JMP callbackasm1(SB)
	MOV $867, X7
	JMP callbackasm1(SB)
	MOV $868, X7
	JMP callbackasm1(SB)
	MOV $869, X7
	JMP callbackasm1(SB)
	MOV $870, X7
	JMP callbackasm1(SB)
	MOV $871, X7
	JMP callbackasm1(SB)
	MOV $872, X7
	JMP callbackasm1(SB)
	MOV $873, X7
	JMP callbackasm1(SB)
	MOV $874, X7
	JMP callbackasm1(SB)
	MOV $875, X7
	JMP callbackasm1(SB)
	MOV $876, X7
	JMP callbackasm1(SB)
	MOV $877, X7
	JMP callbackasm1(SB)
	MOV $878, X7
	JMP callbackasm1(SB)
	MOV $879, X7
	JMP callbackasm1(SB)
	MOV $880, X7
	JMP callbackasm1(SB)
	MOV $881, X7
	JMP callbackasm1(SB)
	MOV $882, X7
	JMP callbackasm1(SB)
	MOV $883, X7
	JMP callbackasm1(SB)
	MOV $884, X7
	JMP callbackasm1(SB)
	MOV $885, X7
	JMP callbackasm1(SB)
	MOV $886, X7
	JMP callbackasm1(SB)
	MOV $887, X7
	JMP callbackasm1(SB)
	MOV $888, X7
	JMP callbackasm1(SB)
	MOV $889, X7
	JMP callbackasm1(SB)
	MOV $890, X7
	JMP callbackasm1(SB)
	MOV $891, X7
	JMP callbackasm1(SB)
	MOV $892, X7
	JMP callbackasm1(SB)
	MOV $893, X7
	JMP callbackasm1(SB)
	MOV $894, X7
	JMP callbackasm1(SB)
	MOV $895, X7
	JMP callbackasm1(SB)
	MOV $896, X7
	JMP callbackasm1(SB)
	MOV $897, X7
	JMP callbackasm1(SB)
	MOV $898, X7
	JMP callbackasm1(SB)
	MOV $899, X7
	JMP callbackasm1(SB)
	MOV $900, X7
	JMP callbackasm1(SB)
	MOV $901, X7
	JMP callbackasm1(SB)
	MOV $902, X7
	JMP callbackasm1(SB)
	MOV $903, X7
	JMP callbackasm1(SB)
	MOV $904, X7
	JMP callbackasm1(SB)
	MOV $905, X7
	JMP callbackasm1(SB)
	MOV $906, X7
	JMP callbackasm1(SB)
	MOV $907, X7
	JMP callbackasm1(SB)
	MOV $908, X7
	JMP callbackasm1(SB)
	MOV $909, X7
	JMP callbackasm1(SB)
	MOV $910, X7
	JMP callbackasm1(SB)
	MOV $911, X7
	JMP callbackasm1(SB)
	MOV $912, X7
	JMP callbackasm1(SB)
	MOV $913, X7
	JMP callbackasm1(SB)
	MOV $914, X7
	JMP callbackasm1(SB)
	MOV $915, X7
	JMP callbackasm1(SB)
	MOV $916, X7
	JMP callbackasm1(SB)
	MOV $917, X7
	JMP callbackasm1(SB)
	MOV $918, X7
	JMP callbackasm1(SB)
	MOV $919, X7
	JMP callbackasm1(SB)
	MOV $920, X7
	JMP callbackasm1(SB)
	MOV $921, X7
	JMP callbackasm1(SB)
	MOV $922, X7
	JMP callbackasm1(SB)
	MOV $923, X7
	JMP callbackasm1(SB)
	MOV $924, X7
	JMP callbackasm1(SB)
	MOV $925, X7
	JMP callbackasm1(SB)
	MOV $926, X7
	JMP callbackasm1(SB)
	MOV $927, X7
	JMP callbackasm1(SB)
	MOV $928, X7
	JMP callbackasm1(SB)
	MOV $929, X7
	JMP callbackasm1(SB)
	MOV $930, X7
	JMP callbackasm1(SB)
	MOV $931, X7
	JMP callbackasm1(SB)
	MOV $932, X7
	JMP callbackasm1(SB)
	MOV $933, X7
	JMP callbackasm1(SB)
	MOV $934, X7
	JMP callbackasm1(SB)
	MOV $935, X7
	JMP callbackasm1(SB)
	MOV $936, X7
	JMP callbackasm1(SB)
	MOV $937, X7
	JMP callbackasm1(SB)
	MOV $938, X7
	JMP callbackasm1(SB)
	MOV $939, X7
	JMP callbackasm1(SB)
	MOV $940, X7
	JMP callbackasm1(SB)
	MOV $941, X7
	JMP callbackasm1(SB)
	MOV $942, X7
	JMP callbackasm1(SB)
	MOV $943, X7
	JMP callbackasm1(SB)
	MOV $944, X7
	JMP callbackasm1(SB)
	MOV $945, X7
	JMP callbackasm1(SB)
	MOV $946, X7
	JMP callbackasm1(SB)
	MOV $947, X7
	JMP callbackasm1(SB)
	MOV $948, X7
	JMP callbackasm1(SB)
	MOV $949, X7
	JMP callbackasm1(SB)
	MOV $950, X7
	JMP callbackasm1(SB)
	MOV $951, X7
	JMP callbackasm1(SB)
	MOV $952, X7
	JMP callbackasm1(SB)
	MOV $953, X7
	JMP callbackasm1(SB)
	MOV $954, X7
	JMP callbackasm1(SB)
	MOV $955, X7
	JMP callbackasm1(SB)
	MOV $956, X7
	JMP callbackasm1(SB)
	MOV $957, X7
	JMP callbackasm1(SB)
	MOV $958, X7
	JMP callbackasm1(SB)
	MOV $959, X7
	JMP callbackasm1(SB)
	MOV $960, X7
	JMP callbackasm1(SB)
	MOV $961, X7
	JMP callbackasm1(SB)
	MOV $962, X7
	JMP callbackasm1(SB)
	MOV $963, X7
	JMP callbackasm1(SB)
	MOV $964, X7
	JMP callbackasm1(SB)
	MOV $965, X7
	JMP callbackasm1(SB)
	MOV $966, X7
	JMP callbackasm1(SB)
	MOV $967, X7
	JMP callbackasm1(SB)
	MOV $968, X7
	JMP callbackasm1(SB)
	MOV $969, X7
	JMP callbackasm1(SB)
	MOV $970, X7
	JMP callbackasm1(SB)
	MOV $971, X7
	JMP callbackasm1(SB)
	MOV $972, X7
	JMP callbackasm1(SB)
	MOV $973, X7
	JMP callbackasm1(SB)
	MOV $974, X7
	JMP callbackasm1(SB)
	MOV $975, X7
	JMP callbackasm1(SB)
	MOV $976, X7
	JMP callbackasm1(SB)
	MOV $977, X7
	JMP callbackasm1(SB)
	MOV $978, X7
	JMP callbackasm1(SB)
	MOV $979, X7
	JMP callbackasm1(SB)
	MOV $980, X7
	JMP callbackasm1(SB)
	MOV $981, X7
	JMP callbackasm1(SB)
	MOV $982, X7
	JMP callbackasm1(SB)
	MOV $983, X7
	JMP callbackasm1(SB)
	MOV $984, X7
	JMP callbackasm1(SB)
	MOV $985, X7
	JMP callbackasm1(SB)
	MOV $986, X7
	JMP callbackasm1(SB)
	MOV $987, X7
	JMP callbackasm1(SB)
	MOV $988, X7
	JMP callbackasm1(SB)
	MOV $989, X7
	JMP callbackasm1(SB)
	MOV $990, X7
	JMP callbackasm1(SB)
	MOV $991, X7
	JMP callbackasm1(SB)
	MOV $992, X7
	JMP callbackasm1(SB)
	MOV $993, X7
	JMP callbackasm1(SB)
	MOV $994, X7
	JMP callbackasm1(SB)
	MOV $995, X7
	JMP callbackasm1(SB)
	MOV $996, X7
	JMP callbackasm1(SB)
	MOV $997, X7
	JMP callbackasm1(SB)
	MOV $998, X7
	JMP callbackasm1(SB)
	MOV $999, X7
	JMP callbackasm1(SB)
	MOV $1000, X7
	JMP callbackasm1(SB)
	MOV $1001, X7
	JMP callbackasm1(SB)
	MOV $1002, X7
	JMP callbackasm1(SB)
	MOV $1003, X7
	JMP callbackasm1(SB)
	MOV $1004, X7
	JMP callbackasm1(SB)
	MOV $1005, X7
	JMP callbackasm1(SB)
	MOV $1006, X7
	JMP callbackasm1(SB)
	MOV $1007, X7
	JMP callbackasm1(SB)
	MOV $1008, X7
	JMP callbackasm1(SB)
	MOV $1009, X7
	JMP callbackasm1(SB)
	MOV $1010, X7
	JMP callbackasm1(SB)
	MOV $1011, X7
	JMP callbackasm1(SB)
	MOV $1012, X7
	JMP callbackasm1(SB)
	MOV $1013, X7
	JMP callbackasm1(SB)
	MOV $1014, X7
	JMP callbackasm1(SB)
	MOV $1015, X7
	JMP callbackasm1(SB)
	MOV $1016, X7
	JMP callbackasm1(SB)
	MOV $1017, X7
	JMP callbackasm1(SB)
	MOV $1018, X7
	JMP callbackasm1(SB)
	MOV $1019, X7
	JMP callbackasm1(SB)
	MOV $1020, X7
	JMP callbackasm1(SB)
	MOV $1021, X7
	JMP callbackasm1(SB)
	MOV $1022, X7
	JMP callbackasm1(SB)
	MOV $1023, X7
	JMP callbackasm1(SB)
	MOV $1024, X7
	JMP callbackasm1(SB)
	MOV $1025, X7
	JMP callbackasm1(SB)
	MOV $1026, X7
	JMP callbackasm1(SB)
	MOV $1027, X7
	JMP callbackasm1(SB)
	MOV $1028, X7
	JMP callbackasm1(SB)
	MOV $1029, X7
	JMP callbackasm1(SB)
	MOV $1030, X7
	JMP callbackasm1(SB)
	MOV $1031, X7
	JMP callbackasm1(SB)
	MOV $1032, X7
	JMP callbackasm1(SB)
	MOV $1033, X7
	JMP callbackasm1(SB)
	MOV $1034, X7
	JMP callbackasm1(SB)
	MOV $1035, X7
	JMP callbackasm1(SB)
	MOV $1036, X7
	JMP callbackasm1(SB)
	MOV $1037, X7
	JMP callbackasm1(SB)
	MOV $1038, X7
	JMP callbackasm1(SB)
	MOV $1039, X7
	JMP callbackasm1(SB)
	MOV $1040, X7
	JMP callbackasm1(SB)
	MOV $1041, X7
	JMP callbackasm1(SB)
	MOV $1042, X7
	JMP callbackasm1(SB)
	MOV $1043, X7
	JMP callbackasm1(SB)
	MOV $1044, X7
	JMP callbackasm1(SB)
	MOV $1045, X7
	JMP callbackasm1(SB)
	MOV $1046, X7
	JMP callbackasm1(SB)
	MOV $1047, X7
	JMP callbackasm1(SB)
	MOV $1048, X7
	JMP callbackasm1(SB)
	MOV $1049, X7
	JMP callbackasm1(SB)
	MOV $1050, X7
	JMP callbackasm1(SB)
	MOV $1051, X7
	JMP callbackasm1(SB)
	MOV $1052, X7
	JMP callbackasm1(SB)
	MOV $1053, X7
	JMP callbackasm1(SB)
	MOV $1054, X7
	JMP callbackasm1(SB)
	MOV $1055, X7
	JMP callbackasm1(SB)
	MOV $1056, X7
	JMP callbackasm1(SB)
	MOV $1057, X7
	JMP callbackasm1(SB)
	MOV $1058, X7
	JMP callbackasm1(SB)
	MOV $1059, X7
	JMP callbackasm1(SB)
	MOV $1060, X7
	JMP callbackasm1(SB)
	MOV $1061, X7
	JMP callbackasm1(SB)
	MOV $1062, X7
	JMP callbackasm1(SB)
	MOV $1063, X7
	JMP callbackasm1(SB)
	MOV $1064, X7
	JMP callbackasm1(SB)
	MOV $1065, X7
	JMP callbackasm1(SB)
	MOV $1066, X7
	JMP callbackasm1(SB)
	MOV $1067, X7
	JMP callbackasm1(SB)
	MOV $1068, X7
	JMP callbackasm1(SB)
	MOV $1069, X7
	JMP callbackasm1(SB)
	MOV $1070, X7
	JMP callbackasm1(SB)
	MOV $1071, X7
	JMP callbackasm1(SB)
	MOV $1072, X7
	JMP callbackasm1(SB)
	MOV $1073, X7
	JMP callbackasm1(SB)
	MOV $1074, X7
	JMP callbackasm1(SB)
	MOV $1075, X7
	JMP callbackasm1(SB)
	MOV $1076, X7
	JMP callbackasm1(SB)
	MOV $1077, X7
	JMP callbackasm1(SB)
	MOV $1078, X7
	JMP callbackasm1(SB)
	MOV $1079, X7
	JMP callbackasm1(SB)
	MOV $1080, X7
	JMP callbackasm1(SB)
	MOV $1081, X7
	JMP callbackasm1(SB)
	MOV $1082, X7
	JMP callbackasm1(SB)
	MOV $1083, X7
	JMP callbackasm1(SB)
	MOV $1084, X7
	JMP callbackasm1(SB)
	MOV $1085, X7
	JMP callbackasm1(SB)
	MOV $1086, X7
	JMP callbackasm1(SB)
	MOV $1087, X7
	JMP callbackasm1(SB)
	MOV $1088, X7
	JMP callbackasm1(SB)
	MOV $1089, X7
	JMP callbackasm1(SB)
	MOV $1090, X7
	JMP callbackasm1(SB)
	MOV $1091, X7
	JMP callbackasm1(SB)
	MOV $1092, X7
	JMP callbackasm1(SB)
	MOV $1093, X7
	JMP callbackasm1(SB)
	MOV $1094, X7
	JMP callbackasm1(SB)
	MOV $1095, X7
	JMP callbackasm1(SB)
	MOV $1096, X7
	JMP callbackasm1(SB)
	MOV $1097, X7
	JMP callbackasm1(SB)
	MOV $1098, X7
	JMP callbackasm1(SB)
	MOV $1099, X7
	JMP callbackasm1(SB)
	MOV $1100, X7
	JMP callbackasm1(SB)
	MOV $1101, X7
	JMP callbackasm1(SB)
	MOV $1102, X7
	JMP callbackasm1(SB)
	MOV $1103, X7
	JMP callbackasm1(SB)
	MOV $1104, X7
	JMP callbackasm1(SB)
	MOV $1105, X7
	JMP callbackasm1(SB)
	MOV $1106, X7
	JMP callbackasm1(SB)
	MOV $1107, X7
	JMP callbackasm1(SB)
	MOV $1108, X7
	JMP callbackasm1(SB)
	MOV $1109, X7
	JMP callbackasm1(SB)
	MOV $1110, X7
	JMP callbackasm1(SB)
	MOV $1111, X7
	JMP callbackasm1(SB)
	MOV $1112, X7
	JMP callbackasm1(SB)
	MOV $1113, X7
	JMP callbackasm1(SB)
	MOV $1114, X7
	JMP callbackasm1(SB)
	MOV $1115, X7
	JMP callbackasm1(SB)
	MOV $1116, X7
	JMP callbackasm1(SB)
	MOV $1117, X7
	JMP callbackasm1(SB)
	MOV $1118, X7
	JMP callbackasm1(SB)
	MOV $1119, X7
	JMP callbackasm1(SB)
	MOV $1120, X7
	JMP callbackasm1(SB)
	MOV $1121, X7
	JMP callbackasm1(SB)
	MOV $1122, X7
	JMP callbackasm1(SB)
	MOV $1123, X7
	JMP callbackasm1(SB)
	MOV $1124, X7
	JMP callbackasm1(SB)
	MOV $1125, X7
	JMP callbackasm1(SB)
	MOV $1126, X7
	JMP callbackasm1(SB)
	MOV $1127, X7
	JMP callbackasm1(SB)
	MOV $1128, X7
	JMP callbackasm1(SB)
	MOV $1129, X7
	JMP callbackasm1(SB)
	MOV $1130, X7
	JMP callbackasm1(SB)
	MOV $1131, X7
	JMP callbackasm1(SB)
	MOV $1132, X7
	JMP callbackasm1(SB)
	MOV $1133, X7
	JMP callbackasm1(SB)
	MOV $1134, X7
	JMP callbackasm1(SB)
	MOV $1135, X7
	JMP callbackasm1(SB)
	MOV $1136, X7
	JMP callbackasm1(SB)
	MOV $1137, X7
	JMP callbackasm1(SB)
	MOV $1138, X7
	JMP callbackasm1(SB)
	MOV $1139, X7
	JMP callbackasm1(SB)
	MOV $1140, X7
	JMP callbackasm1(SB)
	MOV $1141, X7
	JMP callbackasm1(SB)
	MOV $1142, X7
	JMP callbackasm1(SB)
	MOV $1143, X7
	JMP callbackasm1(SB)
	MOV $1144, X7
	JMP callbackasm1(SB)
	MOV $1145, X7
	JMP callbackasm1(SB)
	MOV $1146, X7
	JMP callbackasm1(SB)
	MOV $1147, X7
	JMP callbackasm1(SB)
	MOV $1148, X7
	JMP callbackasm1(SB)
	MOV $1149, X7
	JMP callbackasm1(SB)
	MOV $1150, X7
	JMP callbackasm1(SB)
	MOV $1151, X7
	JMP callbackasm1(SB)
	MOV $1152, X7
	JMP callbackasm1(SB)
	MOV $1153, X7
	JMP callbackasm1(SB)
	MOV $1154, X7
	JMP callbackasm1(SB)
	MOV $1155, X7
	JMP callbackasm1(SB)
	MOV $1156, X7
	JMP callbackasm1(SB)
	MOV $1157, X7
	JMP callbackasm1(SB)
	MOV $1158, X7
	JMP callbackasm1(SB)
	MOV $1159, X7
	JMP callbackasm1(SB)
	MOV $1160, X7
	JMP callbackasm1(SB)
	MOV $1161, X7
	JMP callbackasm1(SB)
	MOV $1162, X7
	JMP callbackasm1(SB)
	MOV $1163, X7
	JMP callbackasm1(SB)
	MOV $1164, X7
	JMP callbackasm1(SB)
	MOV $1165, X7
	JMP callbackasm1(SB)
	MOV $1166, X7
	JMP callbackasm1(SB)
	MOV $1167, X7
	JMP callbackasm1(SB)
	MOV $1168, X7
	JMP callbackasm1(SB)
	MOV $1169, X7
	JMP callbackasm1(SB)
	MOV $1170, X7
	JMP callbackasm1(SB)
	MOV $1171, X7
	JMP callbackasm1(SB)
	MOV $1172, X7
	JMP callbackasm1(SB)
	MOV $1173, X7
	JMP callbackasm1(SB)
	MOV $1174, X7
	JMP callbackasm1(SB)
	MOV $1175, X7
	JMP callbackasm1(SB)
	MOV $1176, X7
	JMP callbackasm1(SB)
	MOV $1177, X7
	JMP callbackasm1(SB)
	MOV $1178, X7
	JMP callbackasm1(SB)
	MOV $1179, X7
	JMP callbackasm1(SB)
	MOV $1180, X7
	JMP callbackasm1(SB)
	MOV $1181, X7
	JMP callbackasm1(SB)
	MOV $1182, X7
	JMP callbackasm1(SB)
	MOV $1183, X7
	JMP callbackasm1(SB)
	MOV $1184, X7
	JMP callbackasm1(SB)
	MOV $1185, X7
	JMP callbackasm1(SB)
	MOV $1186, X7
	JMP callbackasm1(SB)
	MOV $1187, X7
	JMP callbackasm1(SB)
	MOV $1188, X7
	JMP callbackasm1(SB)
	MOV $1189, X7
	JMP callbackasm1(SB)
	MOV $1190, X7
	JMP callbackasm1(SB)
	MOV $1191, X7
	JMP callbackasm1(SB)
	MOV $1192, X7
	JMP callbackasm1(SB)
	MOV $1193, X7
	JMP callbackasm1(SB)
	MOV $1194, X7
	JMP callbackasm1(SB)
	MOV $1195, X7
	JMP callbackasm1(SB)
	MOV $1196, X7
	JMP callbackasm1(SB)
	MOV $1197, X7
	JMP callbackasm1(SB)
	MOV $1198, X7
	JMP callbackasm1(SB)
	MOV $1199, X7
	JMP callbackasm1(SB)
	MOV $1200, X7
	JMP callbackasm1(SB)
	MOV $1201, X7
	JMP callbackasm1(SB)
	MOV $1202, X7
	JMP callbackasm1(SB)
	MOV $1203, X7
	JMP callbackasm1(SB)
	MOV $1204, X7
	JMP callbackasm1(SB)
	MOV $1205, X7
	JMP callbackasm1(SB)
	MOV $1206, X7
	JMP callbackasm1(SB)
	MOV $1207, X7
	JMP callbackasm1(SB)
	MOV $1208, X7
	JMP callbackasm1(SB)
	MOV $1209, X7
	JMP callbackasm1(SB)
	MOV $1210, X7
	JMP callbackasm1(SB)
	MOV $1211, X7
	JMP callbackasm1(SB)
	MOV $1212, X7
	JMP callbackasm1(SB)
	MOV $1213, X7
	JMP callbackasm1(SB)
	MOV $1214, X7
	JMP callbackasm1(SB)
	MOV $1215, X7
	JMP callbackasm1(SB)
	MOV $1216, X7
	JMP callbackasm1(SB)
	MOV $1217, X7
	JMP callbackasm1(SB)
	MOV $1218, X7
	JMP callbackasm1(SB)
	MOV $1219, X7
	JMP callbackasm1(SB)
	MOV $1220, X7
	JMP callbackasm1(SB)
	MOV $1221, X7
	JMP callbackasm1(SB)
	MOV $1222, X7
	JMP callbackasm1(SB)
	MOV $1223, X7
	JMP callbackasm1(SB)
	MOV $1224, X7
	JMP callbackasm1(SB)
	MOV $1225, X7
	JMP callbackasm1(SB)
	MOV $1226, X7
	JMP callbackasm1(SB)
	MOV $1227, X7
	JMP callbackasm1(SB)
	MOV $1228, X7
	JMP callbackasm1(SB)
	MOV $1229, X7
	JMP callbackasm1(SB)
	MOV $1230, X7
	JMP callbackasm1(SB)
	MOV $1231, X7
	JMP callbackasm1(SB)
	MOV $1232, X7
	JMP callbackasm1(SB)
	MOV $1233, X7
	JMP callbackasm1(SB)
	MOV $1234, X7
	JMP callbackasm1(SB)
	MOV $1235, X7
	JMP callbackasm1(SB)
	MOV $1236, X7
	JMP callbackasm1(SB)
	MOV $1237, X7
	JMP callbackasm1(SB)
	MOV $1238, X7
	JMP callbackasm1(SB)
	MOV $1239, X7
	JMP callbackasm1(SB)
	MOV $1240, X7
	JMP callbackasm1(SB)
	MOV $1241, X7
	JMP callbackasm1(SB)
	MOV $1242, X7
	JMP callbackasm1(SB)
	MOV $1243, X7
	JMP callbackasm1(SB)
	MOV $1244, X7
	JMP callbackasm1(SB)
	MOV $1245, X7
	JMP callbackasm1(SB)
	MOV $1246, X7
	JMP callbackasm1(SB)
	MOV $1247, X7
	JMP callbackasm1(SB)
	MOV $1248, X7
	JMP callbackasm1(SB)
	MOV $1249, X7
	JMP callbackasm1(SB)
	MOV $1250, X7
	JMP callbackasm1(SB)
	MOV $1251, X7
	JMP callbackasm1(SB)
	MOV $1252, X7
	JMP callbackasm1(SB)
	MOV $1253, X7
	JMP callbackasm1(SB)
	MOV $1254, X7
	JMP callbackasm1(SB)
	MOV $1255, X7
	JMP callbackasm1(SB)
	MOV $1256, X7
	JMP callbackasm1(SB)
	MOV $1257, X7
	JMP callbackasm1(SB)
	MOV $1258, X7
	JMP callbackasm1(SB)
	MOV $1259, X7
	JMP callbackasm1(SB)
	MOV $1260, X7
	JMP callbackasm1(SB)
	MOV $1261, X7
	JMP callbackasm1(SB)
	MOV $1262, X7
	JMP callbackasm1(SB)
	MOV $1263, X7
	JMP callbackasm1(SB)
	MOV $1264, X7
	JMP callbackasm1(SB)
	MOV $1265, X7
	JMP callbackasm1(SB)
	MOV $1266, X7
	JMP callbackasm1(SB)
	MOV $1267, X7
	JMP callbackasm1(SB)
	MOV $1268, X7
	JMP callbackasm1(SB)
	MOV $1269, X7
	JMP callbackasm1(SB)
	MOV $1270, X7
	JMP callbackasm1(SB)
	MOV $1271, X7
	JMP callbackasm1(SB)
	MOV $1272, X7
	JMP callbackasm1(SB)
	MOV $1273, X7
	JMP callbackasm1(SB)
	MOV $1274, X7
	JMP callbackasm1(SB)
	MOV $1275, X7
	JMP callbackasm1(SB)
	MOV $1276, X7
	JMP callbackasm1(SB)
	MOV $1277, X7
	JMP callbackasm1(SB)
	MOV $1278, X7
	JMP callbackasm1(SB)
	MOV $1279, X7
	JMP callbackasm1(SB)
	MOV $1280, X7
	JMP callbackasm1(SB)
	MOV $1281, X7
	JMP callbackasm1(SB)
	MOV $1282, X7
	JMP callbackasm1(SB)
	MOV $1283, X7
	JMP callbackasm1(SB)
	MOV $1284, X7
	JMP callbackasm1(SB)
	MOV $1285, X7
	JMP callbackasm1(SB)
	MOV $1286, X7
	JMP callbackasm1(SB)
	MOV $1287, X7
	JMP callbackasm1(SB)
	MOV $1288, X7
	JMP callbackasm1(SB)
	MOV $1289, X7
	JMP callbackasm1(SB)
	MOV $1290, X7
	JMP callbackasm1(SB)
	MOV $1291, X7
	JMP callbackasm1(SB)
	MOV $1292, X7
	JMP callbackasm1(SB)
	MOV $1293, X7
	JMP callbackasm1(SB)
	MOV $1294, X7
	JMP callbackasm1(SB)
	MOV $1295, X7
	JMP callbackasm1(SB)
	MOV $1296, X7
	JMP callbackasm1(SB)
	MOV $1297, X7
	JMP callbackasm1(SB)
	MOV $1298, X7
	JMP callbackasm1(SB)
	MOV $1299, X7
	JMP callbackasm1(SB)
	MOV $1300, X7
	JMP callbackasm1(SB)
	MOV $1301, X7
	JMP callbackasm1(SB)
	MOV $1302, X7
	JMP callbackasm1(SB)
	MOV $1303, X7
	JMP callbackasm1(SB)
	MOV $1304, X7
	JMP callbackasm1(SB)
	MOV $1305, X7
	JMP callbackasm1(SB)
	MOV $1306, X7
	JMP callbackasm1(SB)
	MOV $1307, X7
	JMP callbackasm1(SB)
	MOV $1308, X7
	JMP callbackasm1(SB)
	MOV $1309, X7
	JMP callbackasm1(SB)
	MOV $1310, X7
	JMP callbackasm1(SB)
	MOV $1311, X7
	JMP callbackasm1(SB)
	MOV $1312, X7
	JMP callbackasm1(SB)
	MOV $1313, X7
	JMP callbackasm1(SB)
	MOV $1314, X7
	JMP callbackasm1(SB)
	MOV $1315, X7
	JMP callbackasm1(SB)
	MOV $1316, X7
	JMP callbackasm1(SB)
	MOV $1317, X7
	JMP callbackasm1(SB)
	MOV $1318, X7
	JMP callbackasm1(SB)
	MOV $1319, X7
	JMP callbackasm1(SB)
	MOV $1320, X7
	JMP callbackasm1(SB)
	MOV $1321, X7
	JMP callbackasm1(SB)
	MOV $1322, X7
	JMP callbackasm1(SB)
	MOV $1323, X7
	JMP callbackasm1(SB)
	MOV $1324, X7
	JMP callbackasm1(SB)
	MOV $1325, X7
	JMP callbackasm1(SB)
	MOV $1326, X7
	JMP callbackasm1(SB)
	MOV $1327, X7
	JMP callbackasm1(SB)
	MOV $1328, X7
	JMP callbackasm1(SB)
	MOV $1329, X7
	JMP callbackasm1(SB)
	MOV $1330, X7
	JMP callbackasm1(SB)
	MOV $1331, X7
	JMP callbackasm1(SB)
	MOV $1332, X7
	JMP callbackasm1(SB)
	MOV $1333, X7
	JMP callbackasm1(SB)
	MOV $1334, X7
	JMP callbackasm1(SB)
	MOV $1335, X7
	JMP callbackasm1(SB)
	MOV $1336, X7
	JMP callbackasm1(SB)
	MOV $1337, X7
	JMP callbackasm1(SB)
	MOV $1338, X7
	JMP callbackasm1(SB)
	MOV $1339, X7
	JMP callbackasm1(SB)
	MOV $1340, X7
	JMP callbackasm1(SB)
	MOV $1341, X7
	JMP callbackasm1(SB)
	MOV $1342, X7
	JMP callbackasm1(SB)
	MOV $1343, X7
	JMP callbackasm1(SB)
	MOV $1344, X7
	JMP callbackasm1(SB)
	MOV $1345, X7
	JMP callbackasm1(SB)
	MOV $1346, X7
	JMP callbackasm1(SB)
	MOV $1347, X7
	JMP callbackasm1(SB)
	MOV $1348, X7
	JMP callbackasm1(SB)
	MOV $1349, X7
	JMP callbackasm1(SB)
	MOV $1350, X7
	JMP callbackasm1(SB)
	MOV $1351, X7
	JMP callbackasm1(SB)
	MOV $1352, X7
	JMP callbackasm1(SB)
	MOV $1353, X7
	JMP callbackasm1(SB)
	MOV $1354, X7
	JMP callbackasm1(SB)
	MOV $1355, X7
	JMP callbackasm1(SB)
	MOV $1356, X7
	JMP callbackasm1(SB)
	MOV $1357, X7
	JMP callbackasm1(SB)
	MOV $1358, X7
	JMP callbackasm1(SB)
	MOV $1359, X7
	JMP callbackasm1(SB)
	MOV $1360, X7
	JMP callbackasm1(SB)
	MOV $1361, X7
	JMP callbackasm1(SB)
	MOV $1362, X7
	JMP callbackasm1(SB)
	MOV $1363, X7
	JMP callbackasm1(SB)
	MOV $1364, X7
	JMP callbackasm1(SB)
	MOV $1365, X7
	JMP callbackasm1(SB)
	MOV $1366, X7
	JMP callbackasm1(SB)
	MOV $1367, X7
	JMP callbackasm1(SB)
	MOV $1368, X7
	JMP callbackasm1(SB)
	MOV $1369, X7
	JMP callbackasm1(SB)
	MOV $1370, X7
	JMP callbackasm1(SB)
	MOV $1371, X7
	JMP callbackasm1(SB)
	MOV $1372, X7
	JMP callbackasm1(SB)
	MOV $1373, X7
	JMP callbackasm1(SB)
	MOV $1374, X7
	JMP callbackasm1(SB)
	MOV $1375, X7
	JMP callbackasm1(SB)
	MOV $1376, X7
	JMP callbackasm1(SB)
	MOV $1377, X7
	JMP callbackasm1(SB)
	MOV $1378, X7
	JMP callbackasm1(SB)
	MOV $1379, X7
	JMP callbackasm1(SB)
	MOV $1380, X7
	JMP callbackasm1(SB)
	MOV $1381, X7
	JMP callbackasm1(SB)
	MOV $1382, X7
	JMP callbackasm1(SB)
	MOV $1383, X7
	JMP callbackasm1(SB)
	MOV $1384, X7
	JMP callbackasm1(SB)
	MOV $1385, X7
	JMP callbackasm1(SB)
	MOV $1386, X7
	JMP callbackasm1(SB)
	MOV $1387, X7
	JMP callbackasm1(SB)
	MOV $1388, X7
	JMP callbackasm1(SB)
	MOV $1389, X7
	JMP callbackasm1(SB)
	MOV $1390, X7
	JMP callbackasm1(SB)
	MOV $1391, X7
	JMP callbackasm1(SB)
	MOV $1392, X7
	JMP callbackasm1(SB)
	MOV $1393, X7
	JMP callbackasm1(SB)
	MOV $1394, X7
	JMP callbackasm1(SB)
	MOV $1395, X7
	JMP callbackasm1(SB)
	MOV $1396, X7
	JMP callbackasm1(SB)
	MOV $1397, X7
	JMP callbackasm1(SB)
	MOV $1398, X7
	JMP callbackasm1(SB)
	MOV $1399, X7
	JMP callbackasm1(SB)
	MOV $1400, X7
	JMP callbackasm1(SB)
	MOV $1401, X7
	JMP callbackasm1(SB)
	MOV $1402, X7
	JMP callbackasm1(SB)
	MOV $1403, X7
	JMP callbackasm1(SB)
	MOV $1404, X7
	JMP callbackasm1(SB)
	MOV $1405, X7
	JMP callbackasm1(SB)
	MOV $1406, X7
	JMP callbackasm1(SB)
	MOV $1407, X7
	JMP callbackasm1(SB)
	MOV $1408, X7
	JMP callbackasm1(SB)
	MOV $1409, X7
	JMP callbackasm1(SB)
	MOV $1410, X7
	JMP callbackasm1(SB)
	MOV $1411, X7
	JMP callbackasm1(SB)
	MOV $1412, X7
	JMP callbackasm1(SB)
	MOV $1413, X7
	JMP callbackasm1(SB)
	MOV $1414, X7
	JMP callbackasm1(SB)
	MOV $1415, X7
	JMP callbackasm1(SB)
	MOV $1416, X7
	JMP callbackasm1(SB)
	MOV $1417, X7
	JMP callbackasm1(SB)
	MOV $1418, X7
	JMP callbackasm1(SB)
	MOV $1419, X7
	JMP callbackasm1(SB)
	MOV $1420, X7
	JMP callbackasm1(SB)
	MOV $1421, X7
	JMP callbackasm1(SB)
	MOV $1422, X7
	JMP callbackasm1(SB)
	MOV $1423, X7
	JMP callbackasm1(SB)
	MOV $1424, X7
	JMP callbackasm1(SB)
	MOV $1425, X7
	JMP callbackasm1(SB)
	MOV $1426, X7
	JMP callbackasm1(SB)
	MOV $1427, X7
	JMP callbackasm1(SB)
	MOV $1428, X7
	JMP callbackasm1(SB)
	MOV $1429, X7
	JMP callbackasm1(SB)
	MOV $1430, X7
	JMP callbackasm1(SB)
	MOV $1431, X7
	JMP callbackasm1(SB)
	MOV $1432, X7
	JMP callbackasm1(SB)
	MOV $1433, X7
	JMP callbackasm1(SB)
	MOV $1434, X7
	JMP callbackasm1(SB)
	MOV $1435, X7
	JMP callbackasm1(SB)
	MOV $1436, X7
	JMP callbackasm1(SB)
	MOV $1437, X7
	JMP callbackasm1(SB)
	MOV $1438, X7
	JMP callbackasm1(SB)
	MOV $1439, X7
	JMP callbackasm1(SB)
	MOV $1440, X7
	JMP callbackasm1(SB)
	MOV $1441, X7
	JMP callbackasm1(SB)
	MOV $1442, X7
	JMP callbackasm1(SB)
	MOV $1443, X7
	JMP callbackasm1(SB)
	MOV $1444, X7
	JMP callbackasm1(SB)
	MOV $1445, X7
	JMP callbackasm1(SB)
	MOV $1446, X7
	JMP callbackasm1(SB)
	MOV $1447, X7
	JMP callbackasm1(SB)
	MOV $1448, X7
	JMP callbackasm1(SB)
	MOV $1449, X7
	JMP callbackasm1(SB)
	MOV $1450, X7
	JMP callbackasm1(SB)
	MOV $1451, X7
	JMP callbackasm1(SB)
	MOV $1452, X7
	JMP callbackasm1(SB)
	MOV $1453, X7
	JMP callbackasm1(SB)
	MOV $1454, X7
	JMP callbackasm1(SB)
	MOV $1455, X7
	JMP callbackasm1(SB)
	MOV $1456, X7
	JMP callbackasm1(SB)
	MOV $1457, X7
	JMP callbackasm1(SB)
	MOV $1458, X7
	JMP callbackasm1(SB)
	MOV $1459, X7
	JMP callbackasm1(SB)
	MOV $1460, X7
	JMP callbackasm1(SB)
	MOV $1461, X7
	JMP callbackasm1(SB)
	MOV $1462, X7
	JMP callbackasm1(SB)
	MOV $1463, X7
	JMP callbackasm1(SB)
	MOV $1464, X7
	JMP callbackasm1(SB)
	MOV $1465, X7
	JMP callbackasm1(SB)
	MOV $1466, X7
	JMP callbackasm1(SB)
	MOV $1467, X7
	JMP callbackasm1(SB)
	MOV $1468, X7
	JMP callbackasm1(SB)
	MOV $1469, X7
	JMP callbackasm1(SB)
	MOV $1470, X7
	JMP callbackasm1(SB)
	MOV $1471, X7
	JMP callbackasm1(SB)
	MOV $1472, X7
	JMP callbackasm1(SB)
	MOV $1473, X7
	JMP callbackasm1(SB)
	MOV $1474, X7
	JMP callbackasm1(SB)
	MOV $1475, X7
	JMP callbackasm1(SB)
	MOV $1476, X7
	JMP callbackasm1(SB)
	MOV $1477, X7
	JMP callbackasm1(SB)
	MOV $1478, X7
	JMP callbackasm1(SB)
	MOV $1479, X7
	JMP callbackasm1(SB)
	MOV $1480, X7
	JMP callbackasm1(SB)
	MOV $1481, X7
	JMP callbackasm1(SB)
	MOV $1482, X7
	JMP callbackasm1(SB)
	MOV $1483, X7
	JMP callbackasm1(SB)
	MOV $1484, X7
	JMP callbackasm1(SB)
	MOV $1485, X7
	JMP callbackasm1(SB)
	MOV $1486, X7
	JMP callbackasm1(SB)
	MOV $1487, X7
	JMP callbackasm1(SB)
	MOV $1488, X7
	JMP callbackasm1(SB)
	MOV $1489, X7
	JMP callbackasm1(SB)
	MOV $1490, X7
	JMP callbackasm1(SB)
	MOV $1491, X7
	JMP callbackasm1(SB)
	MOV $1492, X7
	JMP callbackasm1(SB)
	MOV $1493, X7
	JMP callbackasm1(SB)
	MOV $1494, X7
	JMP callbackasm1(SB)
	MOV $1495, X7
	JMP callbackasm1(SB)
	MOV $1496, X7
	JMP callbackasm1(SB)
	MOV $1497, X7
	JMP callbackasm1(SB)
	MOV $1498, X7
	JMP callbackasm1(SB)
	MOV $1499, X7
	JMP callbackasm1(SB)
	MOV $1500, X7
	JMP callbackasm1(SB)
	MOV $1501, X7
	JMP callbackasm1(SB)
	MOV $1502, X7
	JMP callbackasm1(SB)
	MOV $1503, X7
	JMP callbackasm1(SB)
	MOV $1504, X7
	JMP callbackasm1(SB)
	MOV $1505, X7
	JMP callbackasm1(SB)
	MOV $1506, X7
	JMP callbackasm1(SB)
	MOV $1507, X7
	JMP callbackasm1(SB)
	MOV $1508, X7
	JMP callbackasm1(SB)
	MOV $1509, X7
	JMP callbackasm1(SB)
	MOV $1510, X7
	JMP callbackasm1(SB)
	MOV $1511, X7
	JMP callbackasm1(SB)
	MOV $1512, X7
	JMP callbackasm1(SB)
	MOV $1513, X7
	JMP callbackasm1(SB)
	MOV $1514, X7
	JMP callbackasm1(SB)
	MOV $1515, X7
	JMP callbackasm1(SB)
	MOV $1516, X7
	JMP callbackasm1(SB)
	MOV $1517, X7
	JMP callbackasm1(SB)
	MOV $1518, X7
	JMP callbackasm1(SB)
	MOV $1519, X7
	JMP callbackasm1(SB)
	MOV $1520, X7
	JMP callbackasm1(SB)
	MOV $1521, X7
	JMP callbackasm1(SB)
	MOV $1522, X7
	JMP callbackasm1(SB)
	MOV $1523, X7
	JMP callbackasm1(SB)
	MOV $1524, X7
	JMP callbackasm1(SB)
	MOV $1525, X7
	JMP callbackasm1(SB)
	MOV $1526, X7
	JMP callbackasm1(SB)
	MOV $1527, X7
	JMP callbackasm1(SB)
	MOV $1528, X7
	JMP callbackasm1(SB)
	MOV $1529, X7
	JMP callbackasm1(SB)
	MOV $1530, X7
	JMP callbackasm1(SB)
	MOV $1531, X7
	JMP callbackasm1(SB)
	MOV $1532, X7
	JMP callbackasm1(SB)
	MOV $1533, X7
	JMP callbackasm1(SB)
	MOV $1534, X7
	JMP callbackasm1(SB)
	MOV $1535, X7
	JMP callbackasm1(SB)
	MOV $1536, X7
	JMP callbackasm1(SB)
	MOV $1537, X7
	JMP callbackasm1(SB)
	MOV $1538, X7
	JMP callbackasm1(SB)
	MOV $1539, X7
	JMP callbackasm1(SB)
	MOV $1540, X7
	JMP callbackasm1(SB)
	MOV $1541, X7
	JMP callbackasm1(SB)
	MOV $1542, X7
	JMP callbackasm1(SB)
	MOV $1543, X7
	JMP callbackasm1(SB)
	MOV $1544, X7
	JMP callbackasm1(SB)
	MOV $1545, X7
	JMP callbackasm1(SB)
	MOV $1546, X7
	JMP callbackasm1(SB)
	MOV $1547, X7
	JMP callbackasm1(SB)
	MOV $1548, X7
	JMP callbackasm1(SB)
	MOV $1549, X7
	JMP callbackasm1(SB)
	MOV $1550, X7
	JMP callbackasm1(SB)
	MOV $1551, X7
	JMP callbackasm1(SB)
	MOV $1552, X7
	JMP callbackasm1(SB)
	MOV $1553, X7
	JMP callbackasm1(SB)
	MOV $1554, X7
	JMP callbackasm1(SB)
	MOV $1555, X7
	JMP callbackasm1(SB)
	MOV $1556, X7
	JMP callbackasm1(SB)
	MOV $1557, X7
	JMP callbackasm1(SB)
	MOV $1558, X7
	JMP callbackasm1(SB)
	MOV $1559, X7
	JMP callbackasm1(SB)
	MOV $1560, X7
	JMP callbackasm1(SB)
	MOV $1561, X7
	JMP callbackasm1(SB)
	MOV $1562, X7
	JMP callbackasm1(SB)
	MOV $1563, X7
	JMP callbackasm1(SB)
	MOV $1564, X7
	JMP callbackasm1(SB)
	MOV $1565, X7
	JMP callbackasm1(SB)
	MOV $1566, X7
	JMP callbackasm1(SB)
	MOV $1567, X7
	JMP callbackasm1(SB)
	MOV $1568, X7
	JMP callbackasm1(SB)
	MOV $1569, X7
	JMP callbackasm1(SB)
	MOV $1570, X7
	JMP callbackasm1(SB)
	MOV $1571, X7
	JMP callbackasm1(SB)
	MOV $1572, X7
	JMP callbackasm1(SB)
	MOV $1573, X7
	JMP callbackasm1(SB)
	MOV $1574, X7
	JMP callbackasm1(SB)
	MOV $1575, X7
	JMP callbackasm1(SB)
	MOV $1576, X7
	JMP callbackasm1(SB)
	MOV $1577, X7
	JMP callbackasm1(SB)
	MOV $1578, X7
	JMP callbackasm1(SB)
	MOV $1579, X7
	JMP callbackasm1(SB)
	MOV $1580, X7
	JMP callbackasm1(SB)
	MOV $1581, X7
	JMP callbackasm1(SB)
	MOV $1582, X7
	JMP callbackasm1(SB)
	MOV $1583, X7
	JMP callbackasm1(SB)
	MOV $1584, X7
	JMP callbackasm1(SB)
	MOV $1585, X7
	JMP callbackasm1(SB)
	MOV $1586, X7
	JMP callbackasm1(SB)
	MOV $1587, X7
	JMP callbackasm1(SB)
	MOV $1588, X7
	JMP callbackasm1(SB)
	MOV $1589, X7
	JMP callbackasm1(SB)
	MOV $1590, X7
	JMP callbackasm1(SB)
	MOV $1591, X7
	JMP callbackasm1(SB)
	MOV $1592, X7
	JMP callbackasm1(SB)
	MOV $1593, X7
	JMP callbackasm1(SB)
	MOV $1594, X7
	JMP callbackasm1(SB)
	MOV $1595, X7
	JMP callbackasm1(SB)
	MOV $1596, X7
	JMP callbackasm1(SB)
	MOV $1597, X7
	JMP callbackasm1(SB)
	MOV $1598, X7
	JMP callbackasm1(SB)
	MOV $1599, X7
	JMP callbackasm1(SB)
	MOV $1600, X7
	JMP callbackasm1(SB)
	MOV $1601, X7
	JMP callbackasm1(SB)
	MOV $1602, X7
	JMP callbackasm1(SB)
	MOV $1603, X7
	JMP callbackasm1(SB)
	MOV $1604, X7
	JMP callbackasm1(SB)
	MOV $1605, X7
	JMP callbackasm1(SB)
	MOV $1606, X7
	JMP callbackasm1(SB)
	MOV $1607, X7
	JMP callbackasm1(SB)
	MOV $1608, X7
	JMP callbackasm1(SB)
	MOV $1609, X7
	JMP callbackasm1(SB)
	MOV $1610, X7
	JMP callbackasm1(SB)
	MOV $1611, X7
	JMP callbackasm1(SB)
	MOV $1612, X7
	JMP callbackasm1(SB)
	MOV $1613, X7
	JMP callbackasm1(SB)
	MOV $1614, X7
	JMP callbackasm1(SB)
	MOV $1615, X7
	JMP callbackasm1(SB)
	MOV $1616, X7
	JMP callbackasm1(SB)
	MOV $1617, X7
	JMP callbackasm1(SB)
	MOV $1618, X7
	JMP callbackasm1(SB)
	MOV $1619, X7
	JMP callbackasm1(SB)
	MOV $1620, X7
	JMP callbackasm1(SB)
	MOV $1621, X7
	JMP callbackasm1(SB)
	MOV $1622, X7
	JMP callbackasm1(SB)
	MOV $1623, X7
	JMP callbackasm1(SB)
	MOV $1624, X7
	JMP callbackasm1(SB)
	MOV $1625, X7
	JMP callbackasm1(SB)
	MOV $1626, X7
	JMP callbackasm1(SB)
	MOV $1627, X7
	JMP callbackasm1(SB)
	MOV $1628, X7
	JMP callbackasm1(SB)
	MOV $1629, X7
	JMP callbackasm1(SB)
	MOV $1630, X7
	JMP callbackasm1(SB)
	MOV $1631, X7
	JMP callbackasm1(SB)
	MOV $1632, X7
	JMP callbackasm1(SB)
	MOV $1633, X7
	JMP callbackasm1(SB)
	MOV $1634, X7
	JMP callbackasm1(SB)
	MOV $1635, X7
	JMP callbackasm1(SB)
	MOV $1636, X7
	JMP callbackasm1(SB)
	MOV $1637, X7
	JMP callbackasm1(SB)
	MOV $1638, X7
	JMP callbackasm1(SB)
	MOV $1639, X7
	JMP callbackasm1(SB)
	MOV $1640, X7
	JMP callbackasm1(SB)
	MOV $1641, X7
	JMP callbackasm1(SB)
	MOV $1642, X7
	JMP callbackasm1(SB)
	MOV $1643, X7
	JMP callbackasm1(SB)
	MOV $1644, X7
	JMP callbackasm1(SB)
	MOV $1645, X7
	JMP callbackasm1(SB)
	MOV $1646, X7
	JMP callbackasm1(SB)
	MOV $1647, X7
	JMP callbackasm1(SB)
	MOV $1648, X7
	JMP callbackasm1(SB)
	MOV $1649, X7
	JMP callbackasm1(SB)
	MOV $1650, X7
	JMP callbackasm1(SB)
	MOV $1651, X7
	JMP callbackasm1(SB)
	MOV $1652, X7
	JMP callbackasm1(SB)
	MOV $1653, X7
	JMP callbackasm1(SB)
	MOV $1654, X7
	JMP callbackasm1(SB)
	MOV $1655, X7
	JMP callbackasm1(SB)
	MOV $1656, X7
	JMP callbackasm1(SB)
	MOV $1657, X7
	JMP callbackasm1(SB)
	MOV $1658, X7
	JMP callbackasm1(SB)
	MOV $1659, X7
	JMP callbackasm1(SB)
	MOV $1660, X7
	JMP callbackasm1(SB)
	MOV $1661, X7
	JMP callbackasm1(SB)
	MOV $1662, X7
	JMP callbackasm1(SB)
	MOV $1663, X7
	JMP callbackasm1(SB)
	MOV $1664, X7
	JMP callbackasm1(SB)
	MOV $1665, X7
	JMP callbackasm1(SB)
	MOV $1666, X7
	JMP callbackasm1(SB)
	MOV $1667, X7
	JMP callbackasm1(SB)
	MOV $1668, X7
	JMP callbackasm1(SB)
	MOV $1669, X7
	JMP callbackasm1(SB)
	MOV $1670, X7
	JMP callbackasm1(SB)
	MOV $1671, X7
	JMP callbackasm1(SB)
	MOV $1672, X7
	JMP callbackasm1(SB)
	MOV $1673, X7
	JMP callbackasm1(SB)
	MOV $1674, X7
	JMP callbackasm1(SB)
	MOV $1675, X7
	JMP callbackasm1(SB)
	MOV $1676, X7
	JMP callbackasm1(SB)
	MOV $1677, X7
	JMP callbackasm1(SB)
	MOV $1678, X7
	JMP callbackasm1(SB)
	MOV $1679, X7
	JMP callbackasm1(SB)
	MOV $1680, X7
	JMP callbackasm1(SB)
	MOV $1681, X7
	JMP callbackasm1(SB)
	MOV $1682, X7
	JMP callbackasm1(SB)
	MOV $1683, X7
	JMP callbackasm1(SB)
	MOV $1684, X7
	JMP callbackasm1(SB)
	MOV $1685, X7
	JMP callbackasm1(SB)
	MOV $1686, X7
	JMP callbackasm1(SB)
	MOV $1687, X7
	JMP callbackasm1(SB)
	MOV $1688, X7
	JMP callbackasm1(SB)
	MOV $1689, X7
	JMP callbackasm1(SB)
	MOV $1690, X7
	JMP callbackasm1(SB)
	MOV $1691, X7
	JMP callbackasm1(SB)
	MOV $1692, X7
	JMP callbackasm1(SB)
	MOV $1693, X7
	JMP callbackasm1(SB)
	MOV $1694, X7
	JMP callbackasm1(SB)
	MOV $1695, X7
	JMP callbackasm1(SB)
	MOV $1696, X7
	JMP callbackasm1(SB)
	MOV $1697, X7
	JMP callbackasm1(SB)
	MOV $1698, X7
	JMP callbackasm1(SB)
	MOV $1699, X7
	JMP callbackasm1(SB)
	MOV $1700, X7
	JMP callbackasm1(SB)
	MOV $1701, X7
	JMP callbackasm1(SB)
	MOV $1702, X7
	JMP callbackasm1(SB)
	MOV $1703, X7
	JMP callbackasm1(SB)
	MOV $1704, X7
	JMP callbackasm1(SB)
	MOV $1705, X7
	JMP callbackasm1(SB)
	MOV $1706, X7
	JMP callbackasm1(SB)
	MOV $1707, X7
	JMP callbackasm1(SB)
	MOV $1708, X7
	JMP callbackasm1(SB)
	MOV $1709, X7
	JMP callbackasm1(SB)
	MOV $1710, X7
	JMP callbackasm1(SB)
	MOV $1711, X7
	JMP callbackasm1(SB)
	MOV $1712, X7
	JMP callbackasm1(SB)
	MOV $1713, X7
	JMP callbackasm1(SB)
	MOV $1714, X7
	JMP callbackasm1(SB)
	MOV $1715, X7
	JMP callbackasm1(SB)
	MOV $1716, X7
	JMP callbackasm1(SB)
	MOV $1717, X7
	JMP callbackasm1(SB)
	MOV $1718, X7
	JMP callbackasm1(SB)
	MOV $1719, X7
	JMP callbackasm1(SB)
	MOV $1720, X7
	JMP callbackasm1(SB)
	MOV $1721, X7
	JMP callbackasm1(SB)
	MOV $1722, X7
	JMP callbackasm1(SB)
	MOV $1723, X7
	JMP callbackasm1(SB)
	MOV $1724, X7
	JMP callbackasm1(SB)
	MOV $1725, X7
	JMP callbackasm1(SB)
	MOV $1726, X7
	JMP callbackasm1(SB)
	MOV $1727, X7
	JMP callbackasm1(SB)
	MOV $1728, X7
	JMP callbackasm1(SB)
	MOV $1729, X7
	JMP callbackasm1(SB)
	MOV $1730, X7
	JMP callbackasm1(SB)
	MOV $1731, X7
	JMP callbackasm1(SB)
	MOV $1732, X7
	JMP callbackasm1(SB)
	MOV $1733, X7
	JMP callbackasm1(SB)
	MOV $1734, X7
	JMP callbackasm1(SB)
	MOV $1735, X7
	JMP callbackasm1(SB)
	MOV $1736, X7
	JMP callbackasm1(SB)
	MOV $1737, X7
	JMP callbackasm1(SB)
	MOV $1738, X7
	JMP callbackasm1(SB)
	MOV $1739, X7
	JMP callbackasm1(SB)
	MOV $1740, X7
	JMP callbackasm1(SB)
	MOV $1741, X7
	JMP callbackasm1(SB)
	MOV $1742, X7
	JMP callbackasm1(SB)
	MOV $1743, X7
	JMP callbackasm1(SB)
	MOV $1744, X7
	JMP callbackasm1(SB)
	MOV $1745, X7
	JMP callbackasm1(SB)
	MOV $1746, X7
	JMP callbackasm1(SB)
	MOV $1747, X7
	JMP callbackasm1(SB)
	MOV $1748, X7
	JMP callbackasm1(SB)
	MOV $1749, X7
	JMP callbackasm1(SB)
	MOV $1750, X7
	JMP callbackasm1(SB)
	MOV $1751, X7
	JMP callbackasm1(SB)
	MOV $1752, X7
	JMP callbackasm1(SB)
	MOV $1753, X7
	JMP callbackasm1(SB)
	MOV $1754, X7
	JMP callbackasm1(SB)
	MOV $1755, X7
	JMP callbackasm1(SB)
	MOV $1756, X7
	JMP callbackasm1(SB)
	MOV $1757, X7
	JMP callbackasm1(SB)
	MOV $1758, X7
	JMP callbackasm1(SB)
	MOV $1759, X7
	JMP callbackasm1(SB)
	MOV $1760, X7
	JMP callbackasm1(SB)
	MOV $1761, X7
	JMP callbackasm1(SB)
	MOV $1762, X7
	JMP callbackasm1(SB)
	MOV $1763, X7
	JMP callbackasm1(SB)
	MOV $1764, X7
	JMP callbackasm1(SB)
	MOV $1765, X7
	JMP callbackasm1(SB)
	MOV $1766, X7
	JMP callbackasm1(SB)
	MOV $1767, X7
	JMP callbackasm1(SB)
	MOV $1768, X7
	JMP callbackasm1(SB)
	MOV $1769, X7
	JMP callbackasm1(SB)
	MOV $1770, X7
	JMP callbackasm1(SB)
	MOV $1771, X7
	JMP callbackasm1(SB)
	MOV $1772, X7
	JMP callbackasm1(SB)
	MOV $1773, X7
	JMP callbackasm1(SB)
	MOV $1774, X7
	JMP callbackasm1(SB)
	MOV $1775, X7
	JMP callbackasm1(SB)
	MOV $1776, X7
	JMP callbackasm1(SB)
	MOV $1777, X7
	JMP callbackasm1(SB)
	MOV $1778, X7
	JMP callbackasm1(SB)
	MOV $1779, X7
	JMP callbackasm1(SB)
	MOV $1780, X7
	JMP callbackasm1(SB)
	MOV $1781, X7
	JMP callbackasm1(SB)
	MOV $1782, X7
	JMP callbackasm1(SB)
	MOV $1783, X7
	JMP callbackasm1(SB)
	MOV $1784, X7
	JMP callbackasm1(SB)
	MOV $1785, X7
	JMP callbackasm1(SB)
	MOV $1786, X7
	JMP callbackasm1(SB)
	MOV $1787, X7
	JMP callbackasm1(SB)
	MOV $1788, X7
	JMP callbackasm1(SB)
	MOV $1789, X7
	JMP callbackasm1(SB)
	MOV $1790, X7
	JMP callbackasm1(SB)
	MOV $1791, X7
	JMP callbackasm1(SB)
	MOV $1792, X7
	JMP callbackasm1(SB)
	MOV $1793, X7
	JMP callbackasm1(SB)
	MOV $1794, X7
	JMP callbackasm1(SB)
	MOV $1795, X7
	JMP callbackasm1(SB)
	MOV $1796, X7
	JMP callbackasm1(SB)
	MOV $1797, X7
	JMP callbackasm1(SB)
	MOV $1798, X7
	JMP callbackasm1(SB)
	MOV $1799, X7
	JMP callbackasm1(SB)
	MOV $1800, X7
	JMP callbackasm1(SB)
	MOV $1801, X7
	JMP callbackasm1(SB)
	MOV $1802, X7
	JMP callbackasm1(SB)
	MOV $1803, X7
	JMP callbackasm1(SB)
	MOV $1804, X7
	JMP callbackasm1(SB)
	MOV $1805, X7
	JMP callbackasm1(SB)
	MOV $1806, X7
	JMP callbackasm1(SB)
	MOV $1807, X7
	JMP callbackasm1(SB)
	MOV $1808, X7
	JMP callbackasm1(SB)
	MOV $1809, X7
	JMP callbackasm1(SB)
	MOV $1810, X7
	JMP callbackasm1(SB)
	MOV $1811, X7
	JMP callbackasm1(SB)
	MOV $1812, X7
	JMP callbackasm1(SB)
	MOV $1813, X7
	JMP callbackasm1(SB)
	MOV $1814, X7
	JMP callbackasm1(SB)
	MOV $1815, X7
	JMP callbackasm1(SB)
	MOV $1816, X7
	JMP callbackasm1(SB)
	MOV $1817, X7
	JMP callbackasm1(SB)
	MOV $1818, X7
	JMP callbackasm1(SB)
	MOV $1819, X7
	JMP callbackasm1(SB)
	MOV $1820, X7
	JMP callbackasm1(SB)
	MOV $1821, X7
	JMP callbackasm1(SB)
	MOV $1822, X7
	JMP callbackasm1(SB)
	MOV $1823, X7
	JMP callbackasm1(SB)
	MOV $1824, X7
	JMP callbackasm1(SB)
	MOV $1825, X7
	JMP callbackasm1(SB)
	MOV $1826, X7
	JMP callbackasm1(SB)
	MOV $1827, X7
	JMP callbackasm1(SB)
	MOV $1828, X7
	JMP callbackasm1(SB)
	MOV $1829, X7
	JMP callbackasm1(SB)
	MOV $1830, X7
	JMP callbackasm1(SB)
	MOV $1831, X7
	JMP callbackasm1(SB)
	MOV $1832, X7
	JMP callbackasm1(SB)
	MOV $1833, X7
	JMP callbackasm1(SB)
	MOV $1834, X7
	JMP callbackasm1(SB)
	MOV $1835, X7
	JMP callbackasm1(SB)
	MOV $1836, X7
	JMP callbackasm1(SB)
	MOV $1837, X7
	JMP callbackasm1(SB)
	MOV $1838, X7
	JMP callbackasm1(SB)
	MOV $1839, X7
	JMP callbackasm1(SB)
	MOV $1840, X7
	JMP callbackasm1(SB)
	MOV $1841, X7
	JMP callbackasm1(SB)
	MOV $1842, X7
	JMP callbackasm1(SB)
	MOV $1843, X7
	JMP callbackasm1(SB)
	MOV $1844, X7
	JMP callbackasm1(SB)
	MOV $1845, X7
	JMP callbackasm1(SB)
	MOV $1846, X7
	JMP callbackasm1(SB)
	MOV $1847, X7
	JMP callbackasm1(SB)
	MOV $1848, X7
	JMP callbackasm1(SB)
	MOV $1849, X7
	JMP callbackasm1(SB)
	MOV $1850, X7
	JMP callbackasm1(SB)
	MOV $1851, X7
	JMP callbackasm1(SB)
	MOV $1852, X7
	JMP callbackasm1(SB)
	MOV $1853, X7
	JMP callbackasm1(SB)
	MOV $1854, X7
	JMP callbackasm1(SB)
	MOV $1855, X7
	JMP callbackasm1(SB)
	MOV $1856, X7
	JMP callbackasm1(SB)
	MOV $1857, X7
	JMP callbackasm1(SB)
	MOV $1858, X7
	JMP callbackasm1(SB)
	MOV $1859, X7
	JMP callbackasm1(SB)
	MOV $1860, X7
	JMP callbackasm1(SB)
	MOV $1861, X7
	JMP callbackasm1(SB)
	MOV $1862, X7
	JMP callbackasm1(SB)
	MOV $1863, X7
	JMP callbackasm1(SB)
	MOV $1864, X7
	JMP callbackasm1(SB)
	MOV $1865, X7
	JMP callbackasm1(SB)
	MOV $1866, X7
	JMP callbackasm1(SB)
	MOV $1867, X7
	JMP callbackasm1(SB)
	MOV $1868, X7
	JMP callbackasm1(SB)
	MOV $1869, X7
	JMP callbackasm1(SB)
	MOV $1870, X7
	JMP callbackasm1(SB)
	MOV $1871, X7
	JMP callbackasm1(SB)
	MOV $1872, X7
	JMP callbackasm1(SB)
	MOV $1873, X7
	JMP callbackasm1(SB)
	MOV $1874, X7
	JMP callbackasm1(SB)
	MOV $1875, X7
	JMP callbackasm1(SB)
	MOV $1876, X7
	JMP callbackasm1(SB)
	MOV $1877, X7
	JMP callbackasm1(SB)
	MOV $1878, X7
	JMP callbackasm1(SB)
	MOV $1879, X7
	JMP callbackasm1(SB)
	MOV $1880, X7
	JMP callbackasm1(SB)
	MOV $1881, X7
	JMP callbackasm1(SB)
	MOV $1882, X7
	JMP callbackasm1(SB)
	MOV $1883, X7
	JMP callbackasm1(SB)
	MOV $1884, X7
	JMP callbackasm1(SB)
	MOV $1885, X7
	JMP callbackasm1(SB)
	MOV $1886, X7
	JMP callbackasm1(SB)
	MOV $1887, X7
	JMP callbackasm1(SB)
	MOV $1888, X7
	JMP callbackasm1(SB)
	MOV $1889, X7
	JMP callbackasm1(SB)
	MOV $1890, X7
	JMP callbackasm1(SB)
	MOV $1891, X7
	JMP callbackasm1(SB)
	MOV $1892, X7
	JMP callbackasm1(SB)
	MOV $1893, X7
	JMP callbackasm1(SB)
	MOV $1894, X7
	JMP callbackasm1(SB)
	MOV $1895, X7
	JMP callbackasm1(SB)
	MOV $1896, X7
	JMP callbackasm1(SB)
	MOV $1897, X7
	JMP callbackasm1(SB)
	MOV $1898, X7
	JMP callbackasm1(SB)
	MOV $1899, X7
	JMP callbackasm1(SB)
	MOV $1900, X7
	JMP callbackasm1(SB)
	MOV $1901, X7
	JMP callbackasm1(SB)
	MOV $1902, X7
	JMP callbackasm1(SB)
	MOV $1903, X7
	JMP callbackasm1(SB)
	MOV $1904, X7
	JMP callbackasm1(SB)
	MOV $1905, X7
	JMP callbackasm1(SB)
	MOV $1906, X7
	JMP callbackasm1(SB)
	MOV $1907, X7
	JMP callbackasm1(SB)
	MOV $1908, X7
	JMP callbackasm1(SB)
	MOV $1909, X7
	JMP callbackasm1(SB)
	MOV $1910, X7
	JMP callbackasm1(SB)
	MOV $1911, X7
	JMP callbackasm1(SB)
	MOV $1912, X7
	JMP callbackasm1(SB)
	MOV $1913, X7
	JMP callbackasm1(SB)
	MOV $1914, X7
	JMP callbackasm1(SB)
	MOV $1915, X7
	JMP callbackasm1(SB)
	MOV $1916, X7
	JMP callbackasm1(SB)
	MOV $1917, X7
	JMP callbackasm1(SB)
	MOV $1918, X7
	JMP callbackasm1(SB)
	MOV $1919, X7
	JMP callbackasm1(SB)
	MOV $1920, X7
	JMP callbackasm1(SB)
	MOV $1921, X7
	JMP callbackasm1(SB)
	MOV $1922, X7
	JMP callbackasm1(SB)
	MOV $1923, X7
	JMP callbackasm1(SB)
	MOV $1924, X7
	JMP callbackasm1(SB)
	MOV $1925, X7
	JMP callbackasm1(SB)
	MOV $1926, X7
	JMP callbackasm1(SB)
	MOV $1927, X7
	JMP callbackasm1(SB)
	MOV $1928, X7
	JMP callbackasm1(SB)
	MOV $1929, X7
	JMP callbackasm1(SB)
	MOV $1930, X7
	JMP callbackasm1(SB)
	MOV $1931, X7
	JMP callbackasm1(SB)
	MOV $1932, X7
	JMP callbackasm1(SB)
	MOV $1933, X7
	JMP callbackasm1(SB)
	MOV $1934, X7
	JMP callbackasm1(SB)
	MOV $1935, X7
	JMP callbackasm1(SB)
	MOV $1936, X7
	JMP callbackasm1(SB)
	MOV $1937, X7
	JMP callbackasm1(SB)
	MOV $1938, X7
	JMP callbackasm1(SB)
	MOV $1939, X7
	JMP callbackasm1(SB)
	MOV $1940, X7
	JMP callbackasm1(SB)
	MOV $1941, X7
	JMP callbackasm1(SB)
	MOV $1942, X7
	JMP callbackasm1(SB)
	MOV $1943, X7
	JMP callbackasm1(SB)
	MOV $1944, X7
	JMP callbackasm1(SB)
	MOV $1945, X7
	JMP callbackasm1(SB)
	MOV $1946, X7
	JMP callbackasm1(SB)
	MOV $1947, X7
	JMP callbackasm1(SB)
	MOV $1948, X7
	JMP callbackasm1(SB)
	MOV $1949, X7
	JMP callbackasm1(SB)
	MOV $1950, X7
	JMP callbackasm1(SB)
	MOV $1951, X7
	JMP callbackasm1(SB)
	MOV $1952, X7
	JMP callbackasm1(SB)
	MOV $1953, X7
	JMP callbackasm1(SB)
	MOV $1954, X7
	JMP callbackasm1(SB)
	MOV $1955, X7
	JMP callbackasm1(SB)
	MOV $1956, X7
	JMP callbackasm1(SB)
	MOV $1957, X7
	JMP callbackasm1(SB)
	MOV $1958, X7
	JMP callbackasm1(SB)
	MOV $1959, X7
	JMP callbackasm1(SB)
	MOV $1960, X7
	JMP callbackasm1(SB)
	MOV $1961, X7
	JMP callbackasm1(SB)
	MOV $1962, X7
	JMP callbackasm1(SB)
	MOV $1963, X7
	JMP callbackasm1(SB)
	MOV $1964, X7
	JMP callbackasm1(SB)
	MOV $1965, X7
	JMP callbackasm1(SB)
	MOV $1966, X7
	JMP callbackasm1(SB)
	MOV $1967, X7
	JMP callbackasm1(SB)
	MOV $1968, X7
	JMP callbackasm1(SB)
	MOV $1969, X7
	JMP callbackasm1(SB)
	MOV $1970, X7
	JMP callbackasm1(SB)
	MOV $1971, X7
	JMP callbackasm1(SB)
	MOV $1972, X7
	JMP callbackasm1(SB)
	MOV $1973, X7
	JMP callbackasm1(SB)
	MOV $1974, X7
	JMP callbackasm1(SB)
	MOV $1975, X7
	JMP callbackasm1(SB)
	MOV $1976, X7
	JMP callbackasm1(SB)
	MOV $1977, X7
	JMP callbackasm1(SB)
	MOV $1978, X7
	JMP callbackasm1(SB)
	MOV $1979, X7
	JMP callbackasm1(SB)
	MOV $1980, X7
	JMP callbackasm1(SB)
	MOV $1981, X7
	JMP callbackasm1(SB)
	MOV $1982, X7
	JMP callbackasm1(SB)
	MOV $1983, X7
	JMP callbackasm1(SB)
	MOV $1984, X7
	JMP callbackasm1(SB)
	MOV $1985, X7
	JMP callbackasm1(SB)
	MOV $1986, X7
	JMP callbackasm1(SB)
	MOV $1987, X7
	JMP callbackasm1(SB)
	MOV $1988, X7
	JMP callbackasm1(SB)
	MOV $1989, X7
	JMP callbackasm1(SB)
	MOV $1990, X7
	JMP callbackasm1(SB)
	MOV $1991, X7
	JMP callbackasm1(SB)
	MOV $1992, X7
	JMP callbackasm1(SB)
	MOV $1993, X7
	JMP callbackasm1(SB)
	MOV $1994, X7
	JMP callbackasm1(SB)
	MOV $1995, X7
	JMP callbackasm1(SB)
	MOV $1996, X7
	JMP callbackasm1(SB)
	MOV $1997, X7
	JMP callbackasm1(SB)
	MOV $1998, X7
	JMP callbackasm1(SB)
	MOV $1999, X7
	JMP callbackasm1(SB)
